B64Decoder class
A utility class for decoding Base64-encoded strings with options for URL-safe variant handling and padding validation.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
String data, {bool validatePadding = true, bool urlSafe = true}) → List< int> -
Decodes a Base64
datastring into bytes. -
decodeWithInfo(
String data, {bool validatePadding = true, bool urlSafe = true}) → B64DecodingInfo -
tryDecode(
String data, {bool validatePadding = true, bool urlSafe = true}) → List< int> ? - Tries to decode a Base64 string, returning null if decoding fails.