B64DecodingInfo class

Constructors

B64DecodingInfo({required bool isUrlSafe, required bool isPaded, required List<int> data})
const

Properties

data List<int>
final
hashCode int
The hash code for this object.
no setterinherited
isPaded bool
final
isUrlSafe bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited