BchBech32Encoder class

Encode data using the Bitcoin Cash (BCH) Bech32 encoding scheme.

Parameters:

  • hrp: The Human-Readable Part (HRP) of the BCH address.
  • netVar: A List representing the network version bytes.
  • data: A List containing the data to be encoded.

Returns: A Bech32 encoded BCH address string.

Inheritance

Constructors

BchBech32Encoder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(String hrp, List<int> netVar, List<int> data) → String
Combine the network version bytes and data.