Bech32Encoder class

A class for encoding data into Bech32 format using the standard Bech32 encoding.

Inheritance

Constructors

Bech32Encoder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

encode(String hrp, List<int> bytes) → String
Encodes data with a Human-Readable Part (HRP) into a Bech32 string.