SegwitBech32Decoder class

A class for decoding Segregated Witness (SegWit) addresses from Bech32 encoding.

Inheritance

Constructors

SegwitBech32Decoder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(String? hrp, String addr) → (int, List<int>)
Decodes a Bech32-encoded SegWit address.