ADAByronAddrConst class
Constants related to Ada Byron era addresses in Cardano.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
chacha20Poly1305Nonce
→ const List<
int> - A predefined nonce used for encryption purposes.
- payloadTag → const int
- An integer representing the payload tag for Ada Byron era addresses.