AdaGenericAddrDecoderResult class

Properties

addressBytes → List<int>
final
baseHashBytes → AdaStakeCredential?
final
byronAddrPayload → ADAByronAddr?
final
hashCode → int
The hash code for this object.
no setterinherited
network → ADANetwork
final
pointer → Pointer?
final
prefixBytes → List<int>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stakeHashBytes → AdaStakeCredential?
final
type → ADAAddressType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited