BlockchainAddressEncoder class abstract

An abstract class for encoding blockchain addresses.

This abstract class defines a common interface for encoding blockchain addresses. Subclasses of this class will implement specific encoding algorithms for different blockchain networks.

Implementers

Constructors

BlockchainAddressEncoder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encodeKey(List<int> pubKey, [Map<String, dynamic> kwargs = const {}]) → String
Encodes a public key into a blockchain address.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited