bip/address/encoders library

A address_encoder liberary for encoding blockchain addresses from public keys.

Classes

ADAByronAddr
ADAByronAddrAttrs
ADAByronAddrConst
Constants related to Ada Byron era addresses in Cardano.
AdaByronAddrDecoder
Implementation of the BlockchainAddressDecoder for Ada Byron address.
ADAByronAddrPayload
ADAByronAddrTypes
Enum representing different address types used in the Ada Byron era.
AdaByronIcarusAddrEncoder
Implementation of the BlockchainAddressEncoder for Ada Byron Icarus address.
AdaByronLegacyAddrEncoder
Implementation of the BlockchainAddressEncoder for Ada Byron Legacy address.
AdaGenericAddrDecoder
Implementation of the BlockchainAddressDecoder for Ada Shelley address.
AdaGenericAddrDecoderResult
AdaPointerAddrEncoder
AdaShelleyAddrDecoder
Implementation of the BlockchainAddressDecoder for Ada Shelley address.
AdaShelleyAddrEncoder
Implementation of the BlockchainAddressEncoder for Ada Shelley address.
AdaShelleyAddrUtils
Utility class for encoding and decoding Ada Shelley addresses.
AdaShelleyEnterpriseAddrEncoder
AdaShelleyEnterpriseDecoder
Implementation of the BlockchainAddressDecoder for Ada Shelley address.
AdaShelleyPointerDecoder
Implementation of the BlockchainAddressDecoder for Ada Shelley address.
AdaShelleyStakingAddrDecoder
Implementation of the BlockchainAddressDecoder for Ada Shelley staking address.
AdaShelleyStakingAddrEncoder
Implementation of the BlockchainAddressEncoder for Ada Shelley staking address.
AdaStakeCredential
AdaStakeCredType
AlgoAddrConst
Constants related to Algorand (Algo) blockchain addresses.
AlgoAddrDecoder
Implementation of the BlockchainAddressDecoder for Algorand (Algo) address.
AlgoAddrEncoder
Implementation of the BlockchainAddressEncoder for Algorand (Algo) address.
AptosAddrConst
AptosAddrDecoder
Implementation of the BlockchainAddressDecoder for Aptos address.
AptosAddrEncoder
Implementation of the BlockchainAddressEncoder for Aptos address.
AptosAddressUtils
AptosSingleKeyEd25519AddrEncoder
AptosSingleKeySecp256k1AddrEncoder
AtomAddrDecoder
Implementation of the BlockchainAddressDecoder for Atom (ATOM) address.
AtomAddrEncoder
Implementation of the BlockchainAddressEncoder for Atom (ATOM) address.
AtomAddressDecodeResult
AtomAddressUtils
AtomEd25519AddrDecoder
Implementation of the BlockchainAddressDecoder for Atom (ATOM) address.
AtomEd25519AddrEncoder
Implementation of the BlockchainAddressEncoder for Atom (ATOM) address.
AtomEthSecp256k1AddrDecoder
Implementation of the BlockchainAddressDecoder for Atom (ATOM) address.
AtomEthSecp256k1AddrEncoder
Implementation of the BlockchainAddressEncoder for Atom (ATOM) address.
AtomNist256P1AddrDecoder
Implementation of the BlockchainAddressDecoder for Atom (ATOM) address.
AtomNist256P1AddrEncoder
Implementation of the BlockchainAddressEncoder for Atom (ATOM) address.
AvaxPChainAddrDecoder
Implementation of the BlockchainAddressDecoder for Avax P-Chain address.
AvaxPChainAddrEncoder
Implementation of the BlockchainAddressEncoder for Avax P-Chain address.
AvaxXChainAddrDecoder
Implementation of the BlockchainAddressDecoder for Avax X-Chain address.
AvaxXChainAddrEncoder
Implementation of the BlockchainAddressEncoder for Avax X-Chain address.
BchAddrConverter
Bitcoin Cash address converter class. It allows to convert a Bitcoin Cash address by changing its HRP and net version.
BchP2PKHAddrDecoder
Implementation of the BlockchainAddressDecoder for P2PKH (Pay-to-Public-Key-Hash) addresses.
BchP2PKHAddrEncoder
Implementation of the BlockchainAddressEncoder for P2PKH (Pay-to-Public-Key-Hash) addresses.
BchP2SHAddrDecoder
Implementation of the BlockchainAddressDecoder for P2SH (Pay-to-Script-Hash) addresses.
BchP2SHAddrEncoder
Implementation of the BlockchainAddressEncoder for P2SH (Pay-to-Script-Hash) addresses.
DecodeAddressResult
EgldAddrDecoder
Implementation of the BlockchainAddressDecoder for Egld (Elrond) address.
EgldAddrEncoder
Implementation of the BlockchainAddressEncoder for Egld (Elrond) address.
EosAddrConst
Constants related to EOS addresses.
EosAddrDecoder
Implementation of the BlockchainAddressDecoder for EOS address.
EosAddrEncoder
Implementation of the BlockchainAddressEncoder for EOS address.
ErgoAddrConst
Constants related to Ergo addresses.
ErgoAddressTypes
An enumeration representing different Ergo address types.
ErgoNetworkTypes
An enumeration representing different Ergo network types.
ErgoP2PKHAddrDecoder
Implementation of the BlockchainAddressDecoder for Ergo address.
ErgoP2PKHAddrEncoder
Implementation of the BlockchainAddressEncoder for Ergo address.
EthAddrConst
Constants related to Ethereum addresses.
EthAddrDecoder
Implementation of the BlockchainAddressDecoder for Ethereum addresses.
EthAddrEncoder
Implementation of the BlockchainAddressEncoder for Ethereum addresses.
EthAddrUtils
Utility class for Ethereum address-related operations.
FilAddrConst
Constants related to Filecoin (FIL) addresses.
FillAddrTypes
Enum representing different address types for Filecoin (FIL) addresses.
FilSecp256k1AddrDecoder
Implementation of the BlockchainAddressDecoder for Filecoin (FIL) addresses.
FilSecp256k1AddrEncoder
Implementation of the BlockchainAddressEncoder for Filecoin (FIL) addresses.
IcxAddrConst
Defines constants related to ICON (ICX) addresses.
IcxAddrDecoder
Implementation of the BlockchainAddressDecoder for ICON (ICX) addresses.
IcxAddrEncoder
Implementation of the BlockchainAddressEncoder for ICON (ICX) addresses.
InjAddrDecoder
Implementation of the BlockchainAddressDecoder for INJ (Injective Protocol) addresses.
InjAddrEncoder
Implementation of the BlockchainAddressEncoder for INJ (Injective Protocol) addresses.
NanoAddrConst
A class that defines constants for Nano (NANO) addresses.
NanoAddrDecoder
Implementation of the BlockchainAddressEncoder for Nano addresses.
NanoAddrEncoder
Implementation of the BlockchainAddressEncoder for Nano addresses.
NearAddrDecoder
Implementation of the BlockchainAddressDecoder for Near Protocol addresses.
NearAddrEncoder
Implementation of the BlockchainAddressEncoder for Near Protocol addresses.
NeoAddrConst
A class that defines constants for Neo (NEO) addresses.
NeoAddrDecoder
Implementation of the BlockchainAddressDecoder for Neo (NEO) addresses.
NeoAddrEncoder
Implementation of the BlockchainAddressEncoder for Neo (NEO) addresses.
OkexAddrDecoder
Implementation of the BlockchainAddressDecoder for OKExChain addresses.
OkexAddrEncoder
Implementation of the BlockchainAddressEncoder for OKExChain addresses.
OneAddrDecoder
Implementation of the BlockchainAddressDecoder for Harmony (ONE) addresses.
OneAddrEncoder
Implementation of the BlockchainAddressEncoder for Harmony (ONE) addresses.
P2PKHAddrDecoder
Implementation of the BlockchainAddressDecoder for P2PKH (Pay-to-Public-Key-Hash) addresses.
P2PKHAddrEncoder
Implementation of the BlockchainAddressEncoder for P2PKH (Pay-to-Public-Key-Hash) addresses.
P2SHAddrConst
Constants related to P2SH (Pay-to-Script-Hash) addresses.
P2SHAddrDecoder
Implementation of the BlockchainAddressDecoder for P2SH (Pay-to-Script-Hash) addresses.
P2SHAddrEncoder
Implementation of the BlockchainAddressEncoder for P2SH (Pay-to-Script-Hash) addresses.
P2TRAddrDecoder
Implementation of the BlockchainAddressDecoder for Segwit v1 (P2TR) addresses.
P2TRAddrEncoder
Implementation of the BlockchainAddressEncoder for Segwit v1 (P2TR) addresses.
P2TRConst
Constants related to P2TR (Pay-to-Taproot) addresses.
P2TRUtils
Utility class for working with P2TR (Pay-to-Taproot) addresses and operations.
P2WPKHAddrConst
Constants related to P2WPKH (Pay-to-Witness-Public-Key-Hash) addresses.
P2WPKHAddrDecoder
Implementation of the BlockchainAddressDecoder for Segwit (P2WPKH) addresses.
P2WPKHAddrEncoder
Implementation of the BlockchainAddressEncoder for Segwit (P2WPKH) addresses.
Pointer
SolAddrDecoder
Implementation of the BlockchainAddressDecoder for Solana (SOL) addresses.
SolAddrEncoder
Implementation of the BlockchainAddressEncoder for Solana (SOL) addresses.
SubstrateEd25519AddrDecoder
Implementation of the BlockchainAddressDecoder for Substrate addresses.
SubstrateEd25519AddrEncoder
Implementation of the BlockchainAddressEncoder for Substrate addresses.
SubstrateGenericAddrDecoder
SubstrateGenericAddrEncoder
SubstrateSecp256k1AddrDecoder
Implementation of the BlockchainAddressDecoder for Substrate addresses.
SubstrateSecp256k1AddrEncoder
Implementation of the BlockchainAddressEncoder for Substrate addresses.
SubstrateSr25519AddrDecoder
Implementation of the BlockchainAddressDecoder for Substrate addresses.
SubstrateSr25519AddrEncoder
Implementation of the BlockchainAddressEncoder for Substrate addresses.
SuiAddrConst
SuiAddrDecoder
Implementation of the BlockchainAddressDecoder for sui address.
SuiAddrEncoder
Implementation of the BlockchainAddressEncoder for sui address.
SuiAddressUtils
SuiPublicKeyAndWeight
SuiSecp256k1AddrEncoder
Implementation of the BlockchainAddressEncoder for sui address.
SuiSecp256r1AddrEncoder
Implementation of the BlockchainAddressEncoder for sui address.
TonAddrDecoder
TonAddrEncoder
TonAddressUtils
TrxAddrDecoder
Implementation of the BlockchainAddressDecoder for TRON (TRX) blockchain addresses.
TrxAddrEncoder
Implementation of the BlockchainAddressEncoder for TRON (TRX) blockchain addresses.
TrxAddressUtils
XlmAddrConst
Constants related to Stellar (XLM) addresses.
XlmAddrDecoder
Implementation of the BlockchainAddressDecoder for Stellar (XLM) blockchain addresses.
XlmAddrDecoderResult
XlmAddrEncoder
Implementation of the BlockchainAddressEncoder for Stellar (XLM) blockchain addresses.
XmrAddrConst
Constants related to Monero (XMR) addresses.
XmrAddrDecoder
Implementation of the BlockchainAddressDecoder for Monero (XMR) blockchain addresses.
XmrAddrEncoder
Implementation of the BlockchainAddressEncoder for Monero (XMR) blockchain addresses.
XmrAddressDecodeResult
XmrIntegratedAddrDecoder
Implementation of the BlockchainAddressDecoder for Monero (XMR) integrated addresses.
XmrIntegratedAddrEncoder
Implementation of the BlockchainAddressEncoder for Monero (XMR) integrated addresses.
XrpAddrDecoder
Implementation of the BlockchainAddressDecoder for ripple (XRP) blockchain addresses.
XrpAddrEncoder
Implementation of the BlockchainAddressEncoder for ripple (XRP) blockchain addresses.
XRPAddressDecodeResult
XRPAddressUtils
XrpXAddrDecoder
Implementation of the BlockchainAddressDecoder for decoding Ripple (XRP) blockchain addresses.
XrpXAddrEncoder
Implementation of the BlockchainAddressEncoder for ripple (XRP) blockchain addresses.
XRPXAddressEncodeResult
XtzAddrDecoder
Implementation of the BlockchainAddressDecoder for Tezos (XTZ) blockchain addresses.
XtzAddrEncoder
Implementation of the BlockchainAddressEncoder for Tezos (XTZ) blockchain addresses.
XtzAddrPrefixes
Enum defining address prefixes for Tezos (XTZ) blockchain addresses.
ZcashAddrDecoder
ZcashAddrEncoder
ZcashAddressUtils
ZcashDecodedAddressResult
ZcashUnifiedAddrEncoder
ZilAddrConst
Constants related to Zilliqa (ZIL) blockchain addresses.
ZilAddrDecoder
A Zilliqa (ZIL) blockchain address decoder that implements the BlockchainAddressDecoder interface.
ZilAddrEncoder
A Zilliqa blockchain address encoder that implements the BlockchainAddressEncoder interface.

Enums

ADAAddressType
ADANetwork
An enumeration of Ada Shelley address network tags.
FriendlyAddressFlags
XlmAddrTypes
Enum representing different types of Stellar (XLM) addresses.
XmrAddressType
XRPAddressType
ZcashAddressType

Exceptions / Errors

AddressConverterException