DecodeAddressResult class

Constructors

DecodeAddressResult({required int workchain, required List<int> hash, required List<FriendlyAddressFlags> flags, bool isUrlSafe = false, bool isPaded = true})

Properties

flags List<FriendlyAddressFlags>
final
hash List<int>
final
hashCode int
The hash code for this object.
no setterinherited
isBounceable bool
no setter
isFriendly bool
no setter
isPaded bool
final
isTestOnly bool
no setter
isUrlSafe bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workchain int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited