TonAddressUtils class

Constructors

TonAddressUtils()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decodeAddress(String address) → DecodeAddressResult
encodeAddress({required List<int> hash, required int workChain, bool bounceable = true, bool testOnly = false, bool urlSafe = false}) → String
fromFriendlyAddress(String address) → DecodeAddressResult
fromRawAddress(String address) → DecodeAddressResult
isFriendly(String source) → bool
isRaw(String source) → bool
validateAddressHash(List<int> bytes) → List<int>