XmrAddrEncoder class

Implementation of the BlockchainAddressEncoder for Monero (XMR) blockchain addresses.

Inheritance

Constructors

XmrAddrEncoder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode({required List<int> pubSpendKey, required List<int> pubViewKey, required List<int> netVarBytes, List<int>? paymentId}) → String
encodeKey(List<int> pubKey, {List<int>? netVersion, List<int>? pubVKey}) → String
Encodes a Monero (XMR) public key and view key as an XMR address.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited