XmrIntegratedAddrEncoder class

Implementation of the BlockchainAddressEncoder for Monero (XMR) integrated addresses.

Implemented types

Constructors

XmrIntegratedAddrEncoder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encodeKey(List<int> pubKey, {List<int>? netVersion, List<int>? paymentId, List<int>? pubVKey}) → String
Encodes a Monero (XMR) public key and view key as an XMR address.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited