XRPXAddressEncodeResult class

Constructors

XRPXAddressEncodeResult({required List<int> hash, int? tag, required ChainType chainType, required String xAddress, required String classicAddress})
const

Properties

chainType ChainType
final
classicAddress String
final
hash List<int>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag int?
final
xAddress String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited