XrpXAddrEncoder class
Implementation of the BlockchainAddressEncoder for ripple (XRP) blockchain addresses.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
encodeHash(
List< int> bytes, {int? tag, ChainType chainType = ChainType.mainnet}) → String -
encodeKey(
List< int> pubKey, {int? tag, ChainType chainType = ChainType.mainnet, EllipticCurveTypes? pubKeyType}) → String -
Encodes the public key into a Ripple (XRP) X-Address.
override
-
encodeKeyWithClassicAddress(
List< int> pubKey, {int? tag, ChainType chainType = ChainType.mainnet, EllipticCurveTypes? pubKeyType}) → XRPXAddressEncodeResult -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited