ZcashAddressUtils class

Constructors

ZcashAddressUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

encodeAddress({required List<int> bytes, required ZcashAddressType type, required ZcashNetwork network, List<ZUnifiedReceiver>? receivers}) String
encodeBase58Addresses({required List<int> bytes, required List<int> prefix, required ZcashAddressType type}) String
encodeBech32Address({required List<int> bytes, required String hrp, required ZcashAddressType type}) String
parseAddress(String address, {ZcashNetwork? expectedNetwork, ZcashAddressType? exceptedType}) ZcashDecodedAddressResult?