bip/bip/bip library
The 'bip' library serves as a comprehensive collection of libraries for working with various Bitcoin Improvement Proposals (BIPs) in the realm of cryptocurrency.
Classes
-
BaseBipCoinConfig<
CONFIG extends BaseCoinConfig> - A base class representing configuration parameters for a cryptocurrency coin.
- BaseCoinConfig
-
Bip32Base<
BIP extends Bip32Base< BIP> > - An abstract base class for BIP-32 hierarchical deterministic key management.
- Bip32ChainCode
- BIP32 chaincode class. It represents a BIP32 chaincode.
- Bip32ChildKey
- Derived child key data
- Bip32Const
-
The
Bip32Constclass defines constants for different Bip32KeyNetVersions. - Bip32Depth
- BIP32 depth class. It represents a BIP32 depth.
- Bip32DeserializedKey
- BIP32 deserialized key class. It represents a key deserialized with the Bip32KeyDeserializer.
- Bip32FingerPrint
- BIP32 fingerprint class. It represents a BIP32 fingerprint.
- Bip32KeyBase
- Bip32KeyData
- BIP32 key data class. It contains all additional data related to a BIP32 key (e.g. depth, chain code, etc...).
- Bip32KeyDataConst
- Class container for BIP32 key data constants.
- Bip32KeyDeserializer
- BIP32 key deserializer class. It deserializes an extended key.
- Bip32KeyIndex
- BIP32 key index class. It represents a BIP32 key index.
- Bip32KeyNetVersions
- Bip32KeyNetVersionsConst
- Contains constants related to BIP32 key network versions.
- Bip32KeySerConst
-
The
Bip32KeySerConstclass contains constants related to the serialization of Bip32 keys. - Bip32KholawEd25519
- A class representing Bip32 hierarchical deterministic keys using the Kholaw elliptic curve with Ed25519 keys.
- Bip32KholawEd25519KeyDerivator
- Bip32KholawEd25519KeyDerivator key derivator
- Bip32KholawEd25519KeyDerivatorBase
- Define an abstract class 'Bip32KholawEd25519KeyDerivatorBase' that implements the 'IBip32KeyDerivator' interface. This class provides a base for deriving Ed25519 keys with the Kholaw scheme.
- Bip32KholawEd25519MstKeyGenerator
- Bip32MasterKey
- derived master key
- Bip32Path
- Represents a BIP32 derivation path, a sequence of key indices.
- Bip32PathConst
- Constants related to the BIP32 derivation path components.
- Bip32PathParser
- A utility class for parsing BIP32 derivation paths and converting them to Bip32Path objects.
- Bip32PrivateKey
- Represents a BIP32 private key with associated data such as the elliptic curve type, key data, and key network versions.
- Bip32PrivateKeySerializer
- BIP32 private key serializer class. It serializes private keys.
- Bip32PublicKey
- Represents a BIP32 public key with associated data such as the elliptic curve type, key data, and key network versions.
- Bip32PublicKeySerializer
- It serializes public keys.
- Bip32Slip10DerivatorConst
- Constants related to the Bip32 Slip10 Derivator.
- Bip32Slip10EcdsaDerivator
- Bip32Slip10Ed25519
- Represents a Bip32Slip10Ed25519 hierarchical deterministic key for Ed25519 curve.
- Bip32Slip10Ed25519Blake2b
- Represents a Bip32Slip10Ed25519Blake2b hierarchical deterministic key for Ed25519-Blake2b curve.
- Bip32Slip10Ed25519Derivator
-
A class that implements the
IBip32KeyDerivatorinterface for Bip32 Slip10 derivation using the Ed25519 elliptic curve. - Bip32Slip10Ed25519MstKeyGenerator
-
A class implementing the
IBip32MstKeyGeneratorinterface to generate master keys for the Ed25519 elliptic curve using Slip-10. - Bip32Slip10MstKeyGeneratorConst
- Bip32Slip10Nist256p1
- Represents a Bip32Slip10Nist256p1 hierarchical deterministic key for NIST256P1 curve.
- Bip32Slip10Nist256p1Hybrid
- Represents a Bip32Slip10Nist256p1Hybrid hierarchical deterministic key for NIST256P1 curve.
- Bip32Slip10Nist256p1MstKeyGenerator
-
A class implementing the
IBip32MstKeyGeneratorinterface to generate master keys for the Nist256p1 elliptic curve using Slip-10. - Bip32Slip10Secp256k1
- Represents a Bip32Slip10Secp256k1 hierarchical deterministic key for SECP256K1 curve.
- Bip32Slip10Secp256k1MstKeyGenerator
-
A class implementing the
IBip32MstKeyGeneratorinterface to generate master keys for the secp256k1 elliptic curve using Slip-10. - Bip38Addr
- bip38 address class
- Bip38Decrypter
- Helper class for BIP38 decryption operations.
- Bip38EcConst
- Constants for BIP38 encryption and decryption operations.
- Bip38EcDecrypter
- Helper class for decrypting BIP38-encrypted private keys.
- Bip38EcKeysGenerator
- Helper class for generating BIP38-encrypted keys.
- Bip38EcUtils
- Utility class for BIP38 encryption and decryption operations.
- Bip38Encrypter
- Helper class for BIP38 encryption and decryption operations.
- Bip38NoEcConst
- Constants for BIP38 encryption and decryption without ECDSA.
- Bip38NoEcDecrypter
- Helper class for decrypting BIP38-encrypted Bitcoin private keys without ECDSA.
- Bip38NoEcEncrypter
- Helper class for encrypting Bitcoin private keys without using ECDSA.
- Bip38NoEcUtils
- Utility class for BIP38 encryption and decryption without ECDSA.
- Bip39EntropyBitLen
- Enum representing the bit lengths for BIP39 entropy values.
- Bip39EntropyGenerator
- BIP39 entropy generator class.
- Bip39Languages
- Enumeration representing the supported languages for BIP-39 mnemonic phrases.
- Bip39LanguagesBase
- Bip39Mnemonic
- BIP-39 mnemonic phrase representation.
- Bip39MnemonicConst
- Constants related to BIP-39 mnemonics, including word counts and word list properties.
- Bip39MnemonicDecoder
- BIP39 (Bitcoin Improvement Proposal 39) mnemonic decoder class.
- Bip39MnemonicEncoder
- BIP39 Mnemonic Encoder for generating mnemonic phrases.
- Bip39MnemonicGenerator
- BIP39 Mnemonic Generator for generating mnemonic phrases.
- Bip39MnemonicValidator
- Validates BIP39 mnemonics based on a specified language.
- Bip39SeedGenerator
- Generates a seed from a Bip39 mnemonic.
- Bip39SeedGeneratorConst
- Constants related to Bip39 seed generation.
-
Bip39WordsListFinder<
BIP39LANG extends Bip39LanguagesBase> - Finds the language of a BIP39 mnemonic based on the words used.
-
Bip39WordsListGetter<
BIP39LANG extends Bip39LanguagesBase> - Retrieves a list of BIP39 words based on the specified language.
- Bip39WordsNum
- Enumeration representing the number of words in a BIP-39 mnemonic phrase.
- Bip44
-
Bip44Base<
BIP44 extends Bip44Base< BIP44> > - Abstract base class for BIP-44 hierarchical deterministic wallets.
- Bip44Conf
- A configuration class for BIP44 coins that defines the key network versions and maps each supported BIP44Coin to its corresponding BipCoinConfig.
- Bip44Const
- Constants related to BIP-44 (Bitcoin Improvement Proposal 44).
- Bip44PrivateKey
- Represents a BIP44 private key for a specific cryptocurrency coin. This class ensures that the elliptic curve type of the private key matches the coin's configuration, and provides various utility methods for working with the private key.
- Bip44PublicKey
- Represents a BIP44 public key for a specific cryptocurrency coin. This class ensures that the elliptic curve type of the public key matches the coin's configuration, and provides various utility methods for working with the public key.
- Bip49
- Bip49Conf
- A configuration class for BIP49 that defines the key network versions and maps each supported BIP49Coin to its corresponding BipCoinConfig.
- Bip49Const
- Constants related to BIP-49 (Bitcoin Improvement Proposal 44).
- Bip84
- Bip84Conf
- A configuration class for BIP84 that defines the key network versions and maps each supported BIP84Coin to its corresponding BipCoinConfig.
- Bip84Const
- Constants related to BIP-84 (Bitcoin Improvement Proposal 84).
- Bip86
- Bip86Conf
- A configuration class for BIP86 that defines the key network versions and maps each supported BIP86Coin to its corresponding BipCoinConfig.
- Bip86Const
- Constants related to BIP-86 (Bitcoin Improvement Proposal 86).
- BipBitcoinCashConf
- A class representing the configuration for Bitcoin Cash (BCH) based on the BIP framework.
- BipCoinConfig
- A base class representing configuration parameters for a cryptocurrency coin.
- BipCoins
- BipLitecoinConf
- A class representing the configuration for Litecoin (LTC) based on the BIP framework.
-
CoinConfig<
T extends BaseCoinConfig> - A base class representing configuration parameters for a cryptocurrency coin.
-
CryptoCoins<
T extends BaseCoinConfig> - An abstract class representing a collection of cryptocurrency coins.
- DefaultZCryptoContext
-
DiversifiableFullViewingKey<
ADDR extends ShieldAddress< DiversifiedTransmissionKey> , IVK extends IncomingViewingKey<ADDR> , OVK extends OutgoingViewingKey, K extends KeyAgreementPrivateKey> - DiversifiedTransmissionKey
- Diversifier
- DiversifierIndex
- Represents an 11-byte Zcash Orchard diversifier index.
- EncodeAddressDefaultParams
- IBip32ChildKeyDerivator
- An abstract class that defines methods for BIP-32 key derivation.
- IBip32MstKeyGenerator
- An abstract class that defines a method for generating master keys from a seed.
-
IncomingViewingKey<
ADDR extends ShieldAddress< DiversifiedTransmissionKey> > - Abstract base for an incoming viewing key that can derive shielded addresses.
-
IZip32ChildKeyDerivator<
PARENTKEY extends CryptoKeyBase< BaseCryptoKeyData< ?, DERIVATIONCONTXT extends CryptoKeyBase<ChainCode?, HdKeyIndex?, KeyDepth?, KeyFingerPrint?> >BaseCryptoKeyData< ?>ChainCode?, HdKeyIndex?, KeyDepth?, KeyFingerPrint?> > - ZIP32 (Zcash Implementation of BIP32) abstractions for hierarchical deterministic key management.
-
IZip32CryptoKey<
KEYDATA extends BaseCryptoKeyData< ChainCode?, HdKeyIndex?, KeyDepth?, KeyFingerPrint?> > - IZip32MasterKeyGenerator
- Interface for ZIP32 master key generation.
- KeyAgreementPrivateKey
- OrchardAddress
- OrchardBindingAuthorizingKey
- OrchardBindingVerificationKey
- OrchardCommitIvkRandomness
- OrchardDiversifiedTransmissionKey
- OrchardDiversifierKey
- OrchardExtendedFullViewKey
- OrchardExtendedSpendingKey
- OrchardFullViewingKey
- OrchardIncomingViewingKey
- OrchardKeyAgreementPrivateKey
- OrchardKeyUtils
- OrchardNullifierDerivingKey
- OrchardOutgoingViewingKey
-
OrchardSigningKey<
V extends OrchardVerifyingKey< V> , K extends OrchardSigningKey<V, K> > - OrchardSpendAuthorizingKey
- OrchardSpendingKey
- OrchardSpendValidatingKey
- OrchardSpendVerificationKey
-
OrchardVerifyingKey<
V extends OrchardVerifyingKey< V> > - OrchardZip32ChildKeyDerivator
- OrchardZip32MasterKeyGenerator
- OutgoingViewingKey
- ReddsaSignature
- Represents a RedDSA signature consisting of r and s components.
-
ReddsaSigningKey<
SCALAR extends CryptoField< SCALAR> , P extends CryptoGroupElement<P, SCALAR> , SCALARNATIVE extends CryptoField<SCALARNATIVE> , PNATIVE extends CryptoGroupElement<PNATIVE, SCALARNATIVE> , V extends VerificationKey<SCALARNATIVE, PNATIVE, V> , SK extends ReddsaSigningKey<SCALAR, P, SCALARNATIVE, PNATIVE, V, SK> > - Abstract base for a RedDSA signing key.
- RedJubJubPrivateKey
- RedJubJubPublicKey
- RedPallasPrivateKey
- RedPallasPublicKey
- SaplingBindingAuthorizingKey
- SaplingBindingVerificationKey
- SaplingDiversifiableFullViewingKey
- SaplingDiversifiedTransmissionKey
- SaplingDiversifierKey
- SaplingExpandedSpendingKey
- SaplingExtendedFullViewKey
- SaplingExtendedSpendingKey
- SaplingFullViewingKey
- SaplingIncomingViewingKey
- SaplingIvk
- SaplingKeyUtils
- SaplingNullifierDerivingKey
- SaplingOutgoingViewingKey
- SaplingPaymentAddress
-
SaplingSigningKey<
V extends SaplingVerifyingKey< V> , K extends SaplingSigningKey<V, K> > - SaplingSpendAuthorizingKey
- SaplingSpendVerificationKey
-
SaplingVerifyingKey<
V extends SaplingVerifyingKey< V> > - SaplingViewingKey
- SaplingZip32ChildKeyDerivator
- SaplingZip32KeyData
- SaplingZip32MasterKeyGenerator
-
ShieldAddress<
PKD extends DiversifiedTransmissionKey> - Represents a generic Shielded address with a transmission key and diversifier.
-
VerificationKey<
SCALAR extends CryptoField< SCALAR> , P extends CryptoGroupElement<P, SCALAR> , V extends VerificationKey<SCALAR, P, V> > - Abstract base for a RedDSA verification key.
- ZcashConf
- ZCryptoContext
- Provides cryptographic primitives and precomputed tables required for ZCash operations (e.g., Poseidon hash, Sinsemilla commitments, and domain-separated commitments).
- Zip32
-
Zip32Base<
SK extends Zip32ExtendedSpendKey< BaseCryptoKeyData< , PK extends Zip32ExtendedFullViewKey<ChainCode?, HdKeyIndex?, KeyDepth?, KeyFingerPrint?> >IncomingViewingKey< , KEYINDEX extends HdKeyIndex, KEYDRIVATOR extends IChildKeyDerivator<ShieldAddress< , BaseCryptoKeyData<DiversifiedTransmissionKey> >ChainCode?, HdKeyIndex?, KeyDepth?, KeyFingerPrint?> >IChildKey, CryptoKeyBase< , MASTERKEYGENERATOR extends IMasterKeyKeyGenerator<BaseCryptoKeyData< ?, CryptoKeyBase<ChainCode?, HdKeyIndex?, KeyDepth?, KeyFingerPrint?> >BaseCryptoKeyData< ?, HdKeyIndex?>ChainCode?, HdKeyIndex?, KeyDepth?, KeyFingerPrint?> >IMasterKey> , KEY extends HDKeyManager<SK, PK, KEYINDEX, KEY> > - Base class for ZIP32 hierarchical deterministic (HD) key managers.
- ZIP32CoinConfig
- A base class representing configuration parameters for a cryptocurrency coin.
- Zip32Const
-
Zip32ExtendedFullViewKey<
IVK extends IncomingViewingKey< ShieldAddress< , KEYDATA extends BaseCryptoKeyData<DiversifiedTransmissionKey> >ChainCode?, HdKeyIndex?, KeyDepth?, KeyFingerPrint?> > - Represents an extended full-view key in ZIP32.
-
Zip32ExtendedSpendKey<
KEYDATA extends BaseCryptoKeyData< ChainCode?, HdKeyIndex?, KeyDepth?, KeyFingerPrint?> > - Represents an extended spending key in ZIP32.
- Zip32Orchard
- Zip32Sapling
Enums
- Bip44Changes
- Enumeration of BIP-44 changes (external and internal).
- Bip44Coins
- Bip44Levels
- Enumeration of BIP-44 levels in hierarchical deterministic wallets.
- Bip49Coins
- An enumeration of supported cryptocurrencies for BIP49. It includes both main networks and test networks of various cryptocurrencies.
- Bip84Coins
- An enumeration of supported cryptocurrencies for BIP84. It includes both main networks and test networks of various cryptocurrencies.
- Bip86Coins
- An enumeration of supported cryptocurrencies for BIP86. It includes both main networks and test networks of various cryptocurrencies.
- ChainType
- CoinProposal
- DefaultHdKeyDerivator
- PrfExpand
- PRF domain identifiers and input shapes.
- PubKeyModes
- Enumeration representing different modes for public keys used in P2PKH addresses.
- ZcashProtocol
- ZIP32Coins
Constants
- derPathHardenedFull → const String
- derPathHardenedShort → const String
- derPathNonHardenedFull → const String
Typedefs
-
CbAddrEncoder<
CONFIG extends BaseCoinConfig> = String Function(EncodeAddressDefaultParams params, CONFIG config)
Exceptions / Errors
- Bip32KeyError
-
The
Bip32KeyErrorclass represents an exception that can be thrown in case of a key-related error during Bip32 key operations. It allows you to provide an optional error message to describe the specific issue. When caught, you can access the error message using thetoString()method or themessageproperty, if provided. - Bip32PathError
-
The
Bip32PathErrorclass represents an exception that can be thrown in case of a path-related error during Bip32 operations. It is designed to handle errors associated with hierarchical deterministic paths. You can include an optional error message to describe the specific issue. To access the error message, use thetoString()method or themessageproperty, if provided. - Bip44DepthError
- Custom exception for errors related to BIP-44 depth.
- OrchardKeyError
- SaplingKeyError
- Zip32Error