Bip32MasterKey class

derived master key

Implemented types

Constructors

Bip32MasterKey({required List<int> key, required Bip32ChainCode chainCode})

Properties

chainCode Bip32ChainCode
chain code
final
hashCode int
The hash code for this object.
no setterinherited
key List<int>
master key
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited