Bip32Const class

The Bip32Const class defines constants for different Bip32KeyNetVersions.

Constructors

Bip32Const()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

kholawKeyNetVersions → const Bip32KeyNetVersions
kholaw key net version
mainNetKeyNetVersions → const Bip32KeyNetVersions
mainnet key net version
testNetKeyNetVersions → const Bip32KeyNetVersions
testnet key network version