Bip32Depth class

BIP32 depth class. It represents a BIP32 depth.

Implemented types
Mixed-in types

Constructors

Bip32Depth(int depth)
factory

Properties

depth int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variables List
no setteroverride

Methods

increase() Bip32Depth
Get a new object with increased depth.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes([Endian endian = Endian.big]) List<int>
Get the depth as bytes.
override
toInt() int
Get the depth as an integer.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fixedLength() int
Get the fixed length in bytes.