Bip32FingerPrint class
BIP32 fingerprint class. It represents a BIP32 fingerprint.
- Implemented types
- Mixed-in types
Constructors
-
Bip32FingerPrint([List<
int> ? fprint]) -
factory
Properties
Methods
-
isMasterKey(
) → bool - Get if the fingerprint corresponds to a master key.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → List< int> -
override
-
toHex(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fixedLength(
) → int - Get the fixed length in bytes.