Bip32KeyIndex class

BIP32 key index class. It represents a BIP32 key index.

Implemented types
Mixed-in types

Constructors

Bip32KeyIndex(int index)
factory
Bip32KeyIndex.fromBytes(List<int> bytes, {Endian endian = Endian.little})
factory
Bip32KeyIndex.hardenIndex(int index)
Harden the specified index and return it.
factory
Bip32KeyIndex.unhardenIndex(int index)
Unharden the specified index and return it.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
final
isHardened bool
Get if the key index is hardened.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variables List
no setteroverride

Methods

harden() Bip32KeyIndex
Get a new Bip32KeyIndex object with the current key index hardened.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes([Endian endian = Endian.big]) List<int>
Get the key index as bytes.
override
toInt() int
Get the key index as an integer.
toString() String
A string representation of this object.
override
unharden() Bip32KeyIndex
Get a new Bip32KeyIndex object with the current key index unhardened.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fixedLength() int
Get the fixed length in bytes.
isHardenedIndex(int index) bool
Get if the specified index is hardened.