Bip32KeyNetVersions class
- Implemented types
Constructors
-
Bip32KeyNetVersions(List<
int> pubNetVer, List<int> privNetVer) -
constractur for Bip32KeyNetVersions
factory
-
Bip32KeyNetVersions.unsafe(List<
int> pubNetVer, List<int> privNetVer) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
private
→ List<
int> -
Get private net version.
no setter
-
privNetVer
→ List<
int> -
final
-
public
→ List<
int> -
Get public net version.
no setter
-
pubNetVer
→ List<
int> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited