Bip32PrivateKeySerializer class
BIP32 private key serializer class. It serializes private keys.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
serialize(
IPrivateKey privKey, Bip32KeyData keyData, [Bip32KeyNetVersions? keyNetVer]) → String - Serialize a private key.
-
serializeBytes(
{required IPrivateKey privKey, required Bip32KeyData keyData, Bip32KeyNetVersions? keyNetVer, bool withPrefix = true}) → List< int>