Bip32KeyBase class abstract

Inheritance
Implementers

Constructors

Bip32KeyBase(Bip32KeyData keyData, EllipticCurveTypes curveType)
const

Properties

curveType EllipticCurveTypes
final
hashCode int
The hash code for this object.
no setterinherited
keyData Bip32KeyData
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toExtended String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toExtendedBytes({bool withPrefix = true}) List<int>
toHex({bool lowerCase = true, String? prefix = ""}) String
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited