Bip38EcConst class

Constants for BIP38 encryption and decryption operations.

Constructors

Bip38EcConst()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

encByteLen → const int
encKeyPrefix → const List<int>
flagBitCompressed → const int
flagBitLotSeq → const int
intPassEncByteLen → const int
Intermediate Passphrase Encryption Constants
intPassMagicNoLotSeq → const List<int>
intPassMagicWithLotSeq → const List<int>
lotNumMaxVal → const int
lotNumMinVal → const int
Lot and Sequence Number Constants
ownerSaltNoLotSeqByteLen → const int
ownerSaltWithLotSeqByteLen → const int
Owner Salt Constants
scryptHalvesKeyLen → const int
scryptHalvesN → const int
scryptHalvesP → const int
scryptHalvesR → const int
scryptPrefactorKeyLen → const int
Scrypt Constants
scryptPrefactorN → const int
scryptPrefactorP → const int
scryptPrefactorR → const int
seedBByteLen → const int
Seed and Encrypted Key Constants
seqNumMaxVal → const int
seqNumMinVal → const int