Bip38EcDecrypter class

Helper class for decrypting BIP38-encrypted private keys.

Constructors

Bip38EcDecrypter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decrypt(String privKeyEnc, String passphrase) → (List<int>, PubKeyModes)
Decrypt a BIP38-encrypted private key with a passphrase.