Bip38EcKeysGenerator class

Helper class for generating BIP38-encrypted keys.

Constructors

Bip38EcKeysGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateIntermediatePassphrase(String passphrase, {int? lotNum, int? sequenceNum}) String
Generate an intermediate passphrase from a regular passphrase.
generatePrivateKey(String intPassphrase, PubKeyModes pubKeyMode) String
Generate a BIP38-encrypted private key from an intermediate passphrase.