Bip39EntropyBitLen class

Enum representing the bit lengths for BIP39 entropy values.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bitLen128 → const Bip39EntropyBitLen
128 bit
bitLen160 → const Bip39EntropyBitLen
160 bit
bitLen192 → const Bip39EntropyBitLen
192 bit
bitLen224 → const Bip39EntropyBitLen
224 bit
bitLen256 → const Bip39EntropyBitLen
256 bit
values → const List<Bip39EntropyBitLen>