Bip39EntropyGenerator class

BIP39 entropy generator class.

Inheritance

Constructors

Bip39EntropyGenerator(Bip39EntropyBitLen bitLen)
Create a BIP39 entropy generator with the specified bit length.

Properties

bitlen int
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

generate() List<int>
Generates and returns random entropy.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isValidEntropyBitLen(int bitLen) bool
Check if a given bit length is a valid BIP39 entropy bit length.
isValidEntropyByteLen(int byteLen) bool
Check if a given byte length is a valid BIP39 entropy byte length.