Bip44Changes enum
Enumeration of BIP-44 changes (external and internal).
Values
- chainExt → const Bip44Changes
-
External chain for receiving funds
const Bip44Changes(0) - chainInt → const Bip44Changes
-
Internal chain for change addresses
const Bip44Changes(1)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
Constructor to associate a value with each instance
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
Bip44Changes> - A constant List of the values in this enum, in order of their declaration.