BipCoinConfig class

A base class representing configuration parameters for a cryptocurrency coin.

Inheritance

Constructors

BipCoinConfig({required CoinNames coinNames, required int coinIdx, required ChainType chainType, required String defPath, required Bip32KeyNetVersions keyNetVer, required List<int>? wifNetVer, required EllipticCurveTypes type, required ADDRENCODER<BipCoinConfig> addressEncoder, DefaultHdKeyDerivator? defaultHdKeyDerivator, Bip32KeyIndex? purpose})
Constructor for BipCoinConfig.
const

Properties

addressEncoder ADDRENCODER<BipCoinConfig>
finalinherited
chainType ChainType
finalinherited
coinIdx int
finalinherited
coinNames CoinNames
Configuration properties.
finalinherited
defaultHdKeyDerivator DefaultHdKeyDerivator?
final
defPath String
finalinherited
hasExtendedKeys bool
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
hasWif bool
no setteroverride
keyNetVer Bip32KeyNetVersions
finalinherited
purpose Bip32KeyIndex?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type EllipticCurveTypes
finalinherited
wifNetVer List<int>?
finalinherited

Methods

copy({CoinNames? coinNames, int? coinIdx, ChainType? chainType, String? defPath, Bip32KeyNetVersions? keyNetVer, List<int>? wifNetVer, EllipticCurveTypes? type, ADDRENCODER<BipCoinConfig>? addressEncoder, Bip32KeyIndex? purpose, DefaultHdKeyDerivator? defaultHdKeyDerivator}) BipCoinConfig
Creates a copy of the BipCoinConfig object with optional properties updated.
override
encodeAddress(EncodeAddressDefaultParams params) String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited