EncodeAddressDefaultParams class
Constructors
Properties
-
chainCode
→ List<
int> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hdPathKey
→ List<
int> ? -
final
- path → String?
-
Ada byron legacy related.
final
-
pubKey
→ List<
int> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ss58Format → int?
-
Substrate related config
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited