Provides cryptographic primitives and precomputed tables required for ZCash operations (e.g., Poseidon hash, Sinsemilla commitments, and domain-separated commitments).
⚠️ Expensive to instantiate: creating a DefaultZCryptoContext allocates
internal tables and constants, so it should be created once and
passed to any code that requires it, rather than recreated repeatedly.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pseudoRando(
{required PallasNativeFp nk, required PallasNativeFp rho}) → PallasNativeFp - $PRF^\mathsf{nfOrchard}(nk, \rho) := Poseidon(nk, \rho)$
-
sinsemillaCommit(
{required VestaNativeFq r, required List< bool> bits, String domain = "z.cash:Orchard-CommitIvk"}) → PallasNativePoint? -
sinsemillaShortCommit(
{required VestaNativeFq r, required List< bool> bits, String domain = "z.cash:Orchard-CommitIvk"}) → PallasNativeFp? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited