OrchardSpendValidatingKey class
- Mixed-in types
Constructors
- OrchardSpendValidatingKey(OrchardSpendVerificationKey pk)
-
factory
-
OrchardSpendValidatingKey.fromBytes(List<
int> bytes) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → OrchardSpendVerificationKey
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variables → List
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → List< int> -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited