Zip32Orchard class

Implemented types

Constructors

Zip32Orchard.fromFullViewKey({required List<int> fvk, required ZCryptoContext context, Bip32KeyData? keyData})
factory
Zip32Orchard.fromSeed(List<int> seedBytes)
factory
Zip32Orchard.fromSpendKey({required List<int> sk, required ZCryptoContext context, Bip32KeyData? keyData})
factory

Properties

chainCode Bip32ChainCode
Gets the chain code associated with this key.
no setteroverride
depth Bip32Depth
Gets the current depth of this key.
no setteroverride
fingerPrint Bip32FingerPrint
Get public key fingerprint.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
index Bip32KeyIndex
Gets the current index of this key.
no setter
isPublicOnly bool
no setter
keyDerivator OrchardZip32ChildKeyDerivator
Gets the key derivator for this key.
no setteroverride
masterKeyGenerator OrchardZip32MasterKeyGenerator
Gets the master key generator for this key.
no setteroverride
privateKey OrchardExtendedSpendingKey
no setteroverride
publicKey OrchardExtendedFullViewKey
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

childKey(Bip32KeyIndex index, ZCryptoContext context) Zip32Orchard
Derives a child key at the given index.
override
derivePath(String path, ZCryptoContext context) Zip32Orchard
Derives a key along a BIP32 path (e.g., "m/32'/0'/0'").
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited