ReddsaSignature class

Represents a RedDSA signature consisting of r and s components.

Mixed-in types

Constructors

ReddsaSignature({required List<int> rBytes, required List<int> sBytes})
ReddsaSignature.deserializeJson(Map<String, dynamic> json)
factory
ReddsaSignature.fromBytes(List<int> bytes)

Properties

hashCode int
The hash code for this object.
no setterinherited
rBytes List<int>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sBytes List<int>
final
variables List
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() List<int>
toLayout({String? property}) Layout<Map<String, dynamic>>
Converts the object into a Layout for serialization.
override
toSerializeBytes({String? property}) List<int>
Serializes the object to bytes using its layout.
inherited
toSerializeJson() Map<String, dynamic>
Serializes the object to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

layout({String? property}) Layout<Map<String, dynamic>>