SaplingExtendedFullViewKey class

Inheritance

Properties

fvk → SaplingFullViewingKey
final
hashCode → int
The hash code for this object.
no setterinherited
keyData → SaplingZip32KeyData
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variables → List
no setteroverride

Methods

deriveInternal() → SaplingExtendedFullViewKey
encodeExtendedFullViewKey(ZIP32CoinConfig config) → String
Encodes the Sapling extended full viewing key as a Bech32 string.
incomingViewingKey(ZCryptoContext context, {Bip44Changes scope = Bip44Changes.chainInt}) → SaplingIncomingViewingKey
Returns the incoming viewing key (IVK) for this extended full-view key.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → List<int>
toDiversifiableFullViewingKey() → SaplingDiversifiableFullViewingKey
toHex({bool lowerCase = true, String? prefix = ""}) → String
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited