SaplingExtendedSpendingKey class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyData → SaplingZip32KeyData
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sk → SaplingExpandedSpendingKey
final
variables → List
no setteroverride

Methods

deriveInternal() → SaplingExtendedSpendingKey
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
spendKeyBytes() → List<int>
override
toBytes() → List<int>
toExtendedFvk() → SaplingExtendedFullViewKey
toHex({bool lowerCase = true, String? prefix = ""}) → String
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited