SaplingViewingKey class

Mixed-in types

Constructors

SaplingViewingKey({required SaplingSpendVerificationKey ak, required SaplingNullifierDerivingKey nk})
const
SaplingViewingKey.fromBytes(List<int> bytes)
factory

Properties

ak → SaplingSpendVerificationKey
final
hashCode → int
The hash code for this object.
no setterinherited
nk → SaplingNullifierDerivingKey
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variables → List
no setteroverride

Methods

ivk() → SaplingIvk
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → List<int>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited