Zip32 class
Constructors
-
Zip32.fromExtendedKey({required List<
int> sk, required ZIP32CoinConfig coinConf, required ZCryptoContext context}) -
factory
-
Zip32.fromSeed({required List<
int> seed, required ZIP32Coins coin, required ZCryptoContext context}) -
factory
-
Zip32.fromSpendKey({required List<
int> sk, required ZIP32Coins coin, required ZCryptoContext context}) -
factory
Properties
- coin → Zip32
-
no setter
- coinConf → ZIP32CoinConfig
-
final
- context → ZCryptoContext
-
final
- deriveDefaultPath → Zip32
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- purpose → Zip32
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specName → String
-
no setter
-
zip32
→ Zip32Base<
Zip32ExtendedSpendKey< BaseCryptoKeyData< , Zip32ExtendedFullViewKey<ChainCode?, HdKeyIndex?, KeyDepth?, KeyFingerPrint?> >IncomingViewingKey< , HdKeyIndex, IChildKeyDerivator<ShieldAddress< , BaseCryptoKeyData<DiversifiedTransmissionKey> >ChainCode?, HdKeyIndex?, KeyDepth?, KeyFingerPrint?> >IChildKey, CryptoKeyBase< , IMasterKeyKeyGenerator<BaseCryptoKeyData< ?, CryptoKeyBase<ChainCode?, HdKeyIndex?, KeyDepth?, KeyFingerPrint?> >BaseCryptoKeyData< ?, HdKeyIndex?>ChainCode?, HdKeyIndex?, KeyDepth?, KeyFingerPrint?> >IMasterKey> , HDKeyManager<Zip32ExtendedSpendKey< >BaseCryptoKeyData< , Zip32ExtendedFullViewKey<ChainCode?, HdKeyIndex?, KeyDepth?, KeyFingerPrint?> >IncomingViewingKey< , HdKeyIndex, dynamic>ShieldAddress< , BaseCryptoKeyData<DiversifiedTransmissionKey> >ChainCode?, HdKeyIndex?, KeyDepth?, KeyFingerPrint?> > -
final
Methods
-
account(
int accIndex) → Zip32 -
addressAt(
DiversifierIndex index, {Bip44Changes scope = Bip44Changes.chainExt}) → String -
defaultAddress(
) → ShieldAddress< DiversifiedTransmissionKey> ? -
findAddress(
{DiversifierIndex? from, Bip44Changes scope = Bip44Changes.chainExt}) → ShieldAddress< DiversifiedTransmissionKey> ? -
findAndEncodeAddress(
{DiversifierIndex? from, Bip44Changes scope = Bip44Changes.chainExt}) → String? -
getViewKey(
{Bip44Changes scope = Bip44Changes.chainExt}) → IncomingViewingKey< ShieldAddress< DiversifiedTransmissionKey> > -
isLevel(
Bip44Levels level) → bool - check level with current bip-44 level
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited