MnemonicLanguages class abstract

An abstract class representing different languages for mnemonic phrases. Classes implementing this interface must provide word lists and language values.

Implementers

Constructors

MnemonicLanguages()

Properties

hashCode → int
The hash code for this object.
no setterinherited
languageValues → List<MnemonicLanguages>
Returns a list of language values, typically containing all available languages.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wordList → List<String>
Returns a list of words that correspond to the language.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited