MnemonicWordsListGetterBase<LANG extends MnemonicLanguages> class abstract

An abstract class for retrieving a list of words based on a specified language.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getByLanguage(LANG language) → MnemonicWordsList
Gets a list of words for a given language.
loadWordsList(LANG language, int wordsNum) → MnemonicWordsList
Loads the words list for a given language and verifies its length.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited