MnemonicValidator<T extends MnemonicDecoderBase<MnemonicLanguages>> class

Utility class for validating and checking the validity of mnemonic phrases.

Implementers

Constructors

MnemonicValidator(T decoder)
Creates a new instance of the MnemonicValidator with the provided decoder.

Properties

decoder → T
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid(String mnemonic) → bool
Checks if a given mnemonic phrase is valid.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(String mnemonic) → void
Validates a given mnemonic phrase using the associated decoder.

Operators

operator ==(Object other) → bool
The equality operator.
inherited