MoneroWordsNum class
An enumeration representing the number of words in a Monero mnemonic.
Properties
- bitlen → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The integer value associated with each word count.
final
- withChecksum → bool
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int? value) → MoneroWordsNum
Constants
-
values
→ const List<
MoneroWordsNum> - wordsNum12 → const MoneroWordsNum
- No checksum, 12 words
- wordsNum13 → const MoneroWordsNum
- With checksum, 13 words
- wordsNum24 → const MoneroWordsNum
- No checksum, 24 words
- wordsNum25 → const MoneroWordsNum
- With checksum, 25 words