MoneroMnemonicWithChecksumEncoder class

A class that encodes entropy into Monero mnemonics with a checksum.

Inheritance

Constructors

MoneroMnemonicWithChecksumEncoder([MoneroLanguages language = MoneroLanguages.english])
Constructs a MoneroMnemonicWithChecksumEncoder with an optional language parameter.

Properties

hashCode int
The hash code for this object.
no setterinherited
language MoneroLanguages
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wordsList MnemonicWordsList
The list of words used for encoding.
finalinherited

Methods

encode(List<int> entropyBytes) Mnemonic
Encodes the provided entropy bytes into a Monero mnemonic with a checksum.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited