UnifiedAddressRequest class

Represents a request for generating a unified address with optional transparent, Sapling, and Orchard components.

Constructors

UnifiedAddressRequest({bool? transparent, bool? sapling, bool? orchard, PubKeyModes? transparentPubKeyMode, List<int>? transparentScriptHash, TransparentAddressRequestType transparentAddressType = TransparentAddressRequestType.p2pkh})
factory
UnifiedAddressRequest.defaultRequest()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
orchard bool?
Whether an Orchard component is requested.
final
orchardAllowed bool
no setter
orchardRequired bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sapling bool?
Whether a Sapling component is requested.
final
saplingAllowed bool
no setter
saplingRequired bool
no setter
transparent bool?
Whether a transparent component is requested.
final
transparentAddressType TransparentAddressRequestType
Type of transparent address to generate.
final
transparentAllowed bool
no setter
transparentPubKeyMode PubKeyModes
PubKey mode for the transparent component.
final
transparentRequired bool
no setter
transparentScriptHash List<int>?
Optional transparent script hash for P2SH addresses.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited