bip/zcash/zcash library

Classes

ReceiverOrchard
ReceiverP2pkh
ReceiverP2sh
ReceiverSapling
ReceiverUnknown
SaplingDerivedAddress
Represents a derived Sapling address and associated payment info.
TransparentDerivedAddress
Represents a derived transparent address and associated keys.
UnifiedAddressRequest
Represents a request for generating a unified address with optional transparent, Sapling, and Orchard components.
UnifiedDerivedAddress
Represents a unified address combining optional Orchard, Sapling, and transparent components.
UnifiedFullViewingKey
Represents a unified full viewing key (UFVK) for transparent, Sapling, and Orchard components.
UnifiedIncomingViewingKey
Represents the unified incoming viewing key (UIVK) for transparent, Sapling, and Orchard components.
UnifiedSpendingKey
Represents a unified spending key (USK) containing transparent, Sapling, and Orchard components.
ZCashAccount
Represents a ZCash account, optionally holding Sapling, Orchard, and Transparent keys.
ZCashAccountConfig
Configuration for a ZCash account, including enabled key types and network info.
ZCashEncodingUtils
ZUnifiedReceiver

Enums

TransparentAddressRequestType
Types of transparent addresses (P2PKH or P2SH).
Typecode
UnifiedReceiverMode
ZCashNetwork

Exceptions / Errors

ZCashKeyEncodingError
ZCashKeyError