CborIterableObject<T extends Iterable<CborObject<Object?>>> class abstract

Iterable

Inheritance
Implementers
Available extensions

Constructors

CborIterableObject(T value)
const

Properties

encoding CborIterableEncodingType
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
An abstract property representing the dynamic value contained in the CBOR object.
finalinherited
variables List
no setterinherited

Methods

allObjectsAs<T extends CborObject<Object?>>() List<T>

Available on CborIterableObject<Iterable<CborObject<Object?>>>, provided by the ExtCborListExtensions extension

Return all CBOR objects as a List<T>.
allRawValuesAs<T>() List<T>

Available on CborIterableObject<Iterable<CborObject<Object?>>>, provided by the ExtCborListExtensions extension

Return all raw values as a List<T>.
cast<E extends CborObject<Object?>>() → E
inherited
encode() List<int>
Encode the object's value to its CBOR representation and return it as a List<int>.
inherited
getValue() Object?
inherited
hasIndex(int index) bool

Available on CborIterableObject<Iterable<CborObject<Object?>>>, provided by the ExtCborListExtensions extension

Returns true if index is valid (within list bounds).
isTypeAt<T extends CborObject<Object?>>(int index) bool

Available on CborIterableObject<Iterable<CborObject<Object?>>>, provided by the ExtCborListExtensions extension

Checks whether the element at index is of type T.
listAt<T extends CborObject<Object?>?>(int index, {bool emptyOnNull = false}) List<T>

Available on CborIterableObject<Iterable<CborObject<Object?>>>, provided by the ExtCborListExtensions extension

Returns element at index as a list of T. If emptyOnNull is true and index is out of bounds → returns [].
mapAt<K extends CborObject<Object?>, V extends CborObject<Object?>>(int index) Map<K, V>

Available on CborIterableObject<Iterable<CborObject<Object?>>>, provided by the ExtCborListExtensions extension

Returns element at index as a typed map.
maybeObjectAt<E, T extends CborObject<Object?>>(int index, E mapper(T e)) → E?

Available on CborIterableObject<Iterable<CborObject<Object?>>>, provided by the ExtCborListExtensions extension

Attempt to transform the CBOR object at index using mapper if it's type T, or return null.
maybeRawMapAt<K, V>(int index) Map<K, V>?

Available on CborIterableObject<Iterable<CborObject<Object?>>>, provided by the ExtCborListExtensions extension

maybeRawValueAt<E, T>(int index, E mapper(T v)) → E?

Available on CborIterableObject<Iterable<CborObject<Object?>>>, provided by the ExtCborListExtensions extension

Attempt to transform the raw value at index using mapper, or return null.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
objectAt<T extends CborObject<Object?>?>(int index) → T

Available on CborIterableObject<Iterable<CborObject<Object?>>>, provided by the ExtCborListExtensions extension

Returns the CBOR object at index as type T.
rawMapAt<K, V>(int index) Map<K, V>

Available on CborIterableObject<Iterable<CborObject<Object?>>>, provided by the ExtCborListExtensions extension

rawValueAt<T extends Object?>(int index) → T

Available on CborIterableObject<Iterable<CborObject<Object?>>>, provided by the ExtCborListExtensions extension

Returns the raw underlying Dart value at index as type T.
sublist<T extends CborObject<Object?>>(int start, [int? end]) CborListValue<T>

Available on CborIterableObject<Iterable<CborObject<Object?>>>, provided by the ExtCborListExtensions extension

toCborHex() String
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited