CborNumeric<T> class
abstract
- Inheritance
-
- Object
- CborObject<
T> - CborNumeric
- Implementers
- Available extensions
Constructors
- CborNumeric(T value)
-
const
Properties
Methods
-
as<
T extends CborObject< (Object?> >{String? operation}) → T -
Available on CborObject<
Object?> , provided by the ExtCborHelper extension -
cast<
E extends CborObject< (Object?> >) → E -
inherited
-
encode(
) → List< int> -
Encode the object's value to its CBOR representation and return it as a
List<int>.inherited -
getValue(
) → Object? -
inherited
-
hasType<
T> () → bool -
Available on CborObject<
Checks whether the value stored in the CborObject has the specified typeObject?> , provided by the ExtCborHelper extensionT. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
objectTo<
E, T extends CborObject< (Object?> >E toe(T e)) → E -
Available on CborObject<
Object?> , provided by the ExtCborHelper extension -
toBigInt(
) → BigInt - Convert the CborNumeric object to a BigInt.
-
toCborHex(
) → String -
inherited
-
toInt(
) → int - Convert the CborNumeric object to an integer.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getCborNumericValue(
CborNumeric val) → BigInt - Retrieve the numeric value from a CborNumeric object and return it as a BigInt. This function is used to extract the numeric value from different CborNumeric subtypes.