CborSerializableException class

Inheritance

Constructors

CborSerializableException(String message, {Map<String, String?>? details})
const
CborSerializableException.deserialize({List<int>? bytes, CborObject<Object?>? object})
factory

Properties

details Map<String, String?>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
relatedNetwork BlockchainNetwork?
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializationIdentifier BlockchainUtilsSerializationIdentifier
no setteroverride
serializationItems List<CborObject<Object?>?>
no setterinherited
variables List
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCbor() CborTagValue<CborObject<Object?>>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

castingFailed<T extends Object?>(Object? value, {String? operation}) CborSerializableException
incorrectTagValue({List<int>? tag}) CborSerializableException