FloatLength enum

Inheritance
Available extensions

Values

bytes16 → const FloatLength
const FloatLength(5, 10)
bytes32 → const FloatLength
const FloatLength(8, 23)
bytes64 → const FloatLength
const FloatLength(11, 52)

Properties

exponentBias int
Calculate the exponent bias for the format.
no setter
exponentBitLength int
Number of bits reserved for the exponent and mantissa in each format.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
mantissaBitLength int
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
numBytes int
Determine the number of bytes required to represent a value in this format.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getByIndex(int index) FloatLength

Constants

values → const List<FloatLength>
A constant List of the values in this enum, in order of their declaration.