FloatLength class

Properties

exponentBias → int
Calculate the exponent bias for the format.
no setter
exponentBitLength → int
Number of bits reserved for the exponent and mantissa in each format.
final
hashCode → int
The hash code for this object.
no setterinherited
mantissaBitLength → int
final
numBytes → int
Determine the number of bytes required to represent a value in this format.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getByIndex(int index) → FloatLength

Constants

bytes16 → const FloatLength
bytes32 → const FloatLength
bytes64 → const FloatLength
values → const List<FloatLength>