AbstractPoint class abstract

An abstract class representing an elliptic curve point.

Implementers

Constructors

AbstractPoint()

Properties

curve → Curve
An abstract property representing the elliptic curve associated with the point.
final
hashCode → int
The hash code for this object.
no setterinherited
isInfinity → bool
A property indicating if the point is at infinity.
no setter
order → BigInt?
A property representing the order of the point.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → BigInt
A property representing the x-coordinate of the point.
no setter
y → BigInt
A property representing the y-coordinate of the point.
no setter

Methods

cast<T extends AbstractPoint>() → T
doublePoint() → AbstractPoint
Doubles a point
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes([EncodeType encodeType = EncodeType.comprossed]) → List<int>
Converts the elliptic curve point to a byte array with the specified encoding type. The default encoding type is 'compressed'.
toHex([EncodeType encodeType = EncodeType.comprossed]) → String
Encodes the elliptic curve point as a hexadecimal string with the specified encoding type. The default encoding type is 'compressed'.
toString() → String
A string representation of this object.
override

Operators

operator *(BigInt other) → AbstractPoint
Multiplies the point by a scalar.
operator +(AbstractPoint other) → AbstractPoint
Adds another point to this point.
operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromBytes(Curve curve, List<int> data, {bool validateEncoding = true, EncodeType? encodeType}) → Tuple<BigInt, BigInt>
Creates an elliptic curve point from its byte representation.