Crc32 class

A class for calculating cyclic redundancy check (CRC32) values.

Note: The Crc32 class can be customized with different algorithms and options for specific use cases.

Constructors

Crc32()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
quickIntDigest(List<int> data) int
Computes a quick integer digest (CRC32) for the provided data.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited