BaseExtendedPointNative class abstract

Inheritance
Implementers

Constructors

BaseExtendedPointNative()

Properties

curve → CurveED
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → BigInt
final
y → BigInt
final

Methods

cast<T extends ECPoint<SCALAR, POINT>>() → T
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → List<int>
inherited
toHex() → String
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator *(BigInt rhs) → BaseExtendedPointNative
inherited
operator +(BaseExtendedPointNative rhs) → BaseExtendedPointNative
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator unary-() → BaseExtendedPointNative
inherited