BaseProjectivePointNative class abstract

Inheritance
Implementers

Constructors

BaseProjectivePointNative()

Properties

curve → CurveFp
final
hashCode → int
The hash code for this object.
no setterinherited
order → BigInt?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → BigInt
final
y → BigInt
final

Methods

cast<T extends ECPoint<SCALAR, POINT>>() → T
inherited
isZero() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes([EncodeType encodeType = EncodeType.comprossed]) → List<int>
override
toHex() → String
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator *(BigInt rhs) → BaseProjectivePointNative
inherited
operator +(BaseProjectivePointNative rhs) → BaseProjectivePointNative
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator unary-() → BaseProjectivePointNative
inherited