ProjectivePointNative class abstract

Inheritance
Implementers

Constructors

ProjectivePointNative()

Properties

curve → CurveFp
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
order → BigInt?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → BigInt
finalinherited
y → BigInt
finalinherited
z → BigInt
final

Methods

cast<T extends ECPoint<SCALAR, POINT>>() → T
inherited
double() → ProjectivePointNative
isZero() → bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes([EncodeType encodeType = EncodeType.comprossed]) → List<int>
inherited
toHex() → String
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator *(BigInt rhs) → BaseProjectivePointNative
inherited
operator +(BaseProjectivePointNative rhs) → BaseProjectivePointNative
inherited
operator ==(Object other) → bool
The equality operator.
inherited
operator unary-() → BaseProjectivePointNative
inherited