Curve class abstract

This is an abstract base class for elliptic curves.

Implemented types
Implementers

Constructors

Curve()

Properties

a BigInt
Coefficient 'a' in the elliptic curve equation
no setter
baselen int
Get the length of the base point in the curve
no setter
hashCode int
The hash code for this object.
no setterinherited
p BigInt
Prime field modulus
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited