GroupElementP2 class

Constructors

GroupElementP2()
factory
GroupElementP2.uncheck({required FieldElement x, required FieldElement y, required FieldElement z})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → FieldElement
final
y → FieldElement
final
z → FieldElement
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited