ProjectiveECCPoint class

Represents a point in projective coordinates on an elliptic curve.

Inheritance

Constructors

ProjectiveECCPoint({required CurveFp curve, required BigInt x, required BigInt y, required BigInt z, BigInt? order, bool generator = false})
Constructs a ProjectiveECCPoint from the given coordinates and optional order and generator flag. The curve parameter specifies the elliptic curve. x, y, and z are the projective coordinates of the point. order is the order of the point, and generator indicates if the point is a generator.
factory
ProjectiveECCPoint.fromAffine(BaseProjectivePointNative point, {bool generator = false})
Constructs a ProjectiveECCPoint from an BaseProjectivePointNative in affine coordinates.
factory
ProjectiveECCPoint.fromBytes({required CurveFp curve, required List<int> data, BigInt? order})
Constructs a ProjectiveECCPoint from a byte representation. The curve parameter specifies the elliptic curve, and data is the byte data. order is the order of the point.
factory
ProjectiveECCPoint.infinity(CurveFp curve)
Constructs a special ProjectiveECCPoint representing infinity on the elliptic curve. The curve parameter specifies the elliptic curve.
factory

Properties

curve → CurveFp
The elliptic curve associated with this point.
final
generator → bool
Indicates whether the point is a generator.
final
hashCode → int
The hash code for this object.
no setteroverride
isEven → bool
no setter
isOdd → bool
no setter
order → BigInt?
The order of the point (can be null if unknown).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → BigInt
Get the x-coordinate of this point in the projective elliptic curve coordinates.
no setteroverride
y → BigInt
Get the y-coordinate of this point in projective elliptic curve coordinates.
no setteroverride
z → BigInt
no setteroverride

Methods

cast<T extends ECPoint<SCALAR, POINT>>() → T
inherited
double() → ProjectiveECCPoint
Doubles a point in projective coordinates on an elliptic curve and returns the result.
override
getCoords() → List<BigInt>
isZero() → bool
check if point is infinity
override
mulAdd(BigInt selfMul, ProjectivePointNative otherPoint, BigInt otherMul) → ProjectiveECCPoint
Multiplies this point by a scalar value selfMul and adds another point otherPoint multiplied by otherMul.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scale() → ProjectiveECCPoint
The coordinates are updated to the scaled values, and the scaled point is returned.
toAffine() → ProjectivAffinePoint
Converts the projective point to an affine point.
toBytes([EncodeType encodeType = EncodeType.comprossed]) → List<int>
inherited
toHex() → String
inherited
toString() → String
A string representation of this object.
inherited
toXonly() → List<int>

Operators

operator *(BigInt scalar) → ProjectiveECCPoint
Multiplies this point by a scalar value.
override
operator +(BaseProjectivePointNative other) → BaseProjectivePointNative
override
operator ==(Object other) → bool
equal operation
override
operator unary-() → ProjectiveECCPoint
operator unary-() → BaseProjectivePointNative
inherited