crypto/crypto/ec/projective/projective library
Classes
- BaseSecp256k1Fe
- BaseSecp256k1FeStorage
-
BaseSecp256k1Ge<
GE extends BaseSecp256k1Fe> -
BaseSecp256k1GeStorage<
GE extends BaseSecp256k1FeStorage> -
BaseSecp256k1ModinvInfo<
B extends BaseSecp256k1ModinvSigned> - BaseSecp256k1ModinvSigned
- BaseSecp256k1Scalar
- MutableInt128
- MutableUint128
- ProjectivAffinePoint
- Represents a point in affine coordinates on an elliptic curve.
- ProjectiveECCPoint
- Represents a point in projective coordinates on an elliptic curve.
- Secp256k1
-
A Dart port of Bitcoin Core's secp256k1 library,
focused on safety during scalar multiplication (
ecmult) to mitigate timing and side-channel attacks. - Secp256k1Const
- Secp256k1ECmultGenContext
- Secp256k1Fe
- Secp256k1FeConst
- Secp256k1FeStorage
- Secp256k1FeStorageConst
- Secp256k1Ge
- Secp256k1GeConst
- Secp256k1Gej
- Secp256k1GeStorage
- Secp256k1GeStorageConst
- Secp256k1ModinvInfo
- Secp256k1ModinvInfoConst
- Secp256k1ModinvSigned
- Secp256k1ModinvSignedConst
- Secp256k1ModinvTrans
- Secp256k1Scalar
- Secp256k1ScalarConst