Secp256k1Utils class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
feFromBytes(Secp256k1Fe f)
→ List<int>
-
create field from bytes
-
feToBytes(Secp256k1Fe f)
→ List<int>
-
convert field to 32 bytes.
-
generatePublicKeyBlind({List<int>? scalarBytes, Secp256k1Scalar? scalar, Secp256k1ECmultGenContext? context, bool secp = true})
→ List<int>?
-
-
geToBytes(Secp256k1Ge element)
→ List<int>
-
-
geToEcPoint(Secp256k1Ge element)
→ ProjectiveECCPoint
-
-
initalizeBlindEcMultContext({List<int>? seed})
→ Secp256k1ECmultGenContext
-
generate ecmult blind context for ecmult using blind alg.
-
loadPublicKey(List<int> pub)
→ Secp256k1Ge?
-
-
scalarFromBytes(List<int> scalarBytes, {bool secp = true, bool validate = true})
→ Secp256k1Scalar
-
convert bytes 32 to scalar.
-
scalarToBytes(Secp256k1Scalar scalar, {bool validate = true, bool clean = false})
→ List<int>
-
convert scalar to 32 bytes
-
scCheck(Secp256k1Scalar scalar)
→ bool
-
check scalar is valid and not zero
-
scCheckFromBytes(List<int> scalarBytes)
→ bool
-
check scalar is valid and not zero
-
secp256k1ECkeyPubkeySerialize(Secp256k1Ge elem, bool compressed)
→ List<int>?
-
convert ge to public key
-
secp256k1ECmultGenBlind(Secp256k1ECmultGenContext ctx, List<int>? seed32)
→ void
-
generate blind context
-
secp256k1Mult({List<int>? scalarBytes, Secp256k1Scalar? scalar, Secp256k1Ge? point, List<int>? pointBytes, bool checkScalar = true})
→ Secp256k1Gej
-
-
secp256k1MultBase({List<int>? scalarBytes, Secp256k1Scalar? scalar, Secp256k1ECmultGenContext? context, bool secp = true})
→ Secp256k1Ge
-