Blake2sTree class

Configuration for the tree structure in Blake2b.

Constructors

Blake2sTree({required int fanout, required int maxDepth, required int leafSize, required int nodeDepth, required int innerDigestLength, required bool lastNode, required int nodeOffset})
const

Properties

fanout → int
The fanout value for the tree structure.
final
hashCode → int
The hash code for this object.
no setterinherited
innerDigestLength → int
The length of the inner digest.
final
lastNode → bool
Indicates whether this is the last node in the tree.
final
leafSize → int
The size of the leaf nodes in the tree.
final
maxDepth → int
The maximum depth of the tree.
final
nodeDepth → int
The depth of the current node in the tree.
final
nodeOffset → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited