MD5 class

A class that represents the MD5 hash algorithm, which is used to compute MD5 message digests. This class implements the SerializableHash interface.

Implemented types

Constructors

MD5()
Creates a new MD5 instance.

Properties

getBlockSize → int
The block size used by the hash algorithm.
no setteroverride
getDigestLength → int
The length of the digest produced by the hash algorithm.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clean() → void
Clean up the internal state and reset hash object to its initial state.
override
cleanSavedState(SH1State savedState) → void
Clean up and reset the saved state of the hash object to its initial state.
override
digest() → List<int>
Generates the final hash digest by assembling and returning the hash state.
override
finish(List<int> out) → Hash
Finalizes the hash computation and stores the hash state in the provided out.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → Hash
Resets the hash computation to its initial state.
override
restoreState(SH1State savedState) → SerializableHash<HashState>
Restores the hash computation state from a previously saved state.
override
saveState() → SH1State
Saves the current hash computation state into a serializable state object.
override
toString() → String
A string representation of this object.
inherited
update(List<int> data) → MD5
Updates the hash computation with the given data.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

hash(List<int> data) → List<int>
Computes the MD5 hash of the provided data and returns the 128-bit (16-byte) MD5 message digest.
override