SHA256 class

The SHA256 class represents the SHA-256 hash algorithm.

Implemented types
Implementers

Constructors

SHA256()

Properties

getBlockSize → int
block size
no setteroverride
getDigestLength → int
digest length
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clean() → void
Clean up the internal state and reset hash object to its initial state.
override
cleanSavedState(SHA256State savedState) → void
Clean up and reset the saved state of the hash object to its initial state.
override
digest() → List<int>
Generates the final hash digest by assembling and returning the hash state.
override
finish(List<int> out) → SerializableHash<HashState>
Finalizes the hash computation and stores the hash state in the provided out.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → SerializableHash<HashState>
Resets the hash computation to its initial state.
override
restoreState(SHA256State savedState) → SerializableHash<HashState>
Restores the hash computation state from a previously saved state.
override
saveState() → SHA256State
Saves the current hash computation state into a serializable state object.
override
toString() → String
A string representation of this object.
inherited
update(List<int> data, {int? length}) → SerializableHash<HashState>
Updates the hash computation with the given data.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

hash(List<int> data) → List<int>
Computes the SHA-256 hash of the provided data.
override