XXHash64 class

Inheritance

Constructors

XXHash64({int bitLength = 64})

Properties

getBlockSize → int
The block size used by the hash algorithm.
final
getDigestLength → int
The length of the digest produced by the hash algorithm.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clean() → void
Cleans sensitive data in the hash instance.
override
cleanSavedState(HashBytesState savedState) → void
Cleans sensitive data from the saved hash state.
override
digest() → List<int>
Retrieves the hash digest.
override
finish(List<int> out) → XXHash64
Finalizes the hash computation and stores the result in the provided out buffer.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → XXHash64
Resets the hash to its initial state.
override
restoreState(HashBytesState savedState) → SerializableHash<HashState>
Restores the hash state from a saved state.
override
saveState() → HashBytesState
Saves the current hash state.
override
toString() → String
A string representation of this object.
inherited
update(List<int> data) → Hash
Updates the hash with the provided data.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

hash(List<int> data, {int bitlength = 64}) → List<int>
Creates a combined hash code for a number of objects.
override