HMAC<T extends HashState> class

The HMAC class represents a Hash-based Message Authentication Code.

It computes a MAC using a given hash function with a secret key and input data.

Implemented types

Constructors

HMAC(CbHashFunc<T> hash, List<int> key, [int? blockSize])
Creates an HMAC instance with the specified hash function and secret key.

Properties

getBlockSize → int
block size
no setteroverride
getDigestLength → int
digest length
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clean() → void
Clean up the internal state and reset hash object to its initial state.
override
cleanSavedState(T savedState) → void
Clean up and reset the saved state of the hash object to its initial state.
override
digest() → List<int>
Generates the final hash digest by assembling and returning the hash state in a List<int>.
override
finish(List<int> out) → HMAC<HashState>
Finalizes the hash computation and stores the hash state in the provided out. Parameters:
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → HMAC<HashState>
Resets the hash computation to its initial state.
override
restoreState(T savedState) → HMAC<HashState>
Restores the hash computation state from a previously saved state.
override
saveState() → T
Saves the current hash computation state into a serializable state object.
override
toString() → String
A string representation of this object.
inherited
update(List<int> data) → Hash
Updates the hash computation with the given data.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

hmac(CbHashFunc<HashState> hash, List<int> key, List<int> data) → List<int>
Calculates an HMAC using a specified hash function, a secret key, and input data.