JwtHeader class

Constructors

JwtHeader({JwtSupportedAlgorithm? alg = JwtSupportedAlgorithm.eddsa, String typ = 'JWT', String? kid, String? cty, Map<String, dynamic>? customClaims})
JwtHeader.fromJson(Map<String, dynamic> json)
factory

Properties

alg → JwtSupportedAlgorithm?
final
cty → String?
final
customClaims → Map<String, dynamic>?
final
hashCode → int
The hash code for this object.
no setterinherited
kid → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typ → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited