JwtPayload class

Constructors

JwtPayload({String? iss, String? sub, List<String>? aud, int? exp, int? nbf, int? iat, String? jti, String? name, Map<String, dynamic>? customClaims})
JwtPayload.fromJson(Map<String, dynamic> json)
factory

Properties

aud → List<String>?
final
customClaims → Map<String, dynamic>?
final
exp → int?
final
hashCode → int
The hash code for this object.
no setterinherited
iat → int?
final
iss → String?
final
jti → String?
final
name → String?
final
nbf → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sub → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited