crypto/crypto/prng/fortuna library

Classes

FortunaPRNG
The FortunaPRNG class represents an implementation of the Fortuna pseudorandom number generator (PRNG) algorithm.

Typedefs

CbGenerateRandom = List<int> Function(int length)
The CbGenerateRandom typedef defines a function signature for generating random data with a specified length.