FortunaPRNG class

The FortunaPRNG class represents an implementation of the Fortuna pseudorandom number generator (PRNG) algorithm.

Mixed-in types

Constructors

FortunaPRNG([List<int>? seed])
Constructor for the FortunaPRNG class, initializing the pseudorandom number generator (PRNG).
FortunaPRNG.fromEntropy(List<int> entropy)

Properties

hashCode int
The hash code for this object.
no setterinherited
nextUint32 int
no setter
nextUint8 int
Generates and returns the next 8 bits (1 byte) of pseudorandom data from the Fortuna PRNG.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

nextBool() bool
Generates a random boolean value.
inherited
nextBytes(int length) List<int>
Generates and returns a bytes containing pseudorandom data of the specified length from the Fortuna PRNG.
override
nextDouble() double
Generates a non-negative random floating point value uniformly distributed in the range from 0.0, inclusive, to 1.0, exclusive.
override
nextInt(int max) int
Generates a non-negative random integer uniformly distributed in the range from 0, inclusive, to max, exclusive.
override
nextU32({Endian endian = Endian.little}) int
inherited
nextU64({Endian endian = Endian.little}) BigInt
inherited
nextU8() int
inherited
nextUint64() BigInt
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited