toBytes method

List<int> toBytes()

Converts the Schnorrkel public key to a byte representation.

This method returns a byte array representing the Schnorrkel public key.

Implementation

List<int> toBytes() {
  return _publicKey.clone();
}