XModemCrc class

A class for calculating and verifying XModem CRC (Cyclic Redundancy Check).

Constructors

XModemCrc()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

digestSize int
Returns the size of the XModem CRC digest, which is always 2 bytes (16 bits).
no setter

Static Methods

quickDigest(List<int> data) List<int>
Calculates the XModem CRC (Cyclic Redundancy Check) for the given data.