Bls12FpConst class

Constants for the BLS12-381 base field GF(p). All values are expressed using BigInt.

Constructors

Bls12FpConst()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

inv BigInt
Montgomery inverse of the modulus modulo 2⁶⁴ (BigInt-backed).
no setter
modulus Bls12Fp
Modulus represented as fixed-size limb elements.
final
p BigInt
Prime modulus p of BLS12-381 as a single BigInt.
final