FF1Flexible class

FF1 format-preserving encryption using a flexible numeral string.

Inheritance

Constructors

FF1Flexible({required AES aes, int radix = 2})

Properties

aes AES
finalinherited
config FF1Radix
finalinherited
hashCode int
The hash code for this object.
no setterinherited
radix int
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

decrypt(FlexibleNumeralString x, {List<int> tweak = const []}) FlexibleNumeralString
Performs FF1 decryption on x, optionally using a tweak.
inherited
encrypt(FlexibleNumeralString x, {List<int> tweak = const []}) FlexibleNumeralString
Performs FF1 encryption on x, optionally using a tweak.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited