JubJubNativeFieldElement<F extends JubJubNativeFieldElement<F>> class abstract

Inheritance
Implemented types
Implementers

Constructors

JubJubNativeFieldElement(BigInt v)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
p BigInt
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
v BigInt
final

Methods

charBits() List<bool>
override
double() → F
inherited
identity() → F
invert() → F?
inherited
isZero() bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sqrt() FieldSqrtResult<F>
inherited
square() → F
inherited
toBits() List<bool>
override
toBytes() List<int>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator *(F other) → F
inherited
operator +(F other) → F
inherited
operator -(F other) → F
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator unary-() → F
inherited