JubJubNativeFr class

Element of the JubJub scalar field Fr.

Inheritance
Implemented types
Mixed-in types

Constructors

JubJubNativeFr(BigInt v)
JubJubNativeFr.fromBytes(List<int> bytes)
factory
JubJubNativeFr.fromBytes64(List<int> bytes)
factory
JubJubNativeFr.minusOne()
factory
JubJubNativeFr.nP(BigInt v)
Creates a field element assuming v is already in canonical form.
JubJubNativeFr.one()
factory
JubJubNativeFr.random()
factory
JubJubNativeFr.zero()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
p BigInt
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
v BigInt
finalinherited
variables List
no setteroverride

Methods

charBits() List<bool>
inherited
double() JubJubNativeFr
override
identity() JubJubNativeFr
override
invert() JubJubNativeFr?
override
isZero() bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pow(BigInt v) JubJubNativeFr
sqrt() FieldSqrtResult<JubJubNativeFr>
override
square() JubJubNativeFr
override
toBits() List<bool>
inherited
toBytes() List<int>
override
toString() String
A string representation of this object.
inherited

Operators

operator *(JubJubNativeFr other) JubJubNativeFr
override
operator +(JubJubNativeFr other) JubJubNativeFr
override
operator -(JubJubNativeFr other) JubJubNativeFr
override
operator /(JubJubNativeFr o) JubJubNativeFr
operator ==(Object other) bool
The equality operator.
inherited
operator unary-() JubJubNativeFr
override