PastaSqrtTables<F extends PastaFieldElement<F>> class

Constructors

PastaSqrtTables({required int hashXor, required int hashMod, required F rootOfUnity, required F one})
factory

Properties

g0 List<F>
final
g1 List<F>
final
g2 List<F>
final
g3 List<F>
final
hashCode int
The hash code for this object.
no setterinherited
hashMod int
final
hashXor int
final
inv List<int>
final
rootOfUnity → F
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getHash(F x) int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sqrtAlt(F u) FieldSqrtResult<F>
Returns (isSquare, sqrtValue)
sqrtCommon(F uv, F v) → F
sqrtRatio(F num, F div) FieldSqrtResult<F>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited