FieldSqrtResult<F extends CryptoField<F>> class

Mixed-in types

Constructors

FieldSqrtResult(F result, bool isSquare)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isSquare bool
final
result → F
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variables List
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sqrtOrNull() → F?
Returns the square root if this element is a quadratic residue, otherwise returns null.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited