PedersenHashNative class

Inheritance

Constructors

PedersenHashNative({List<List<List<JubJubNativePoint>>>? generators})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

hash({required Personalization personalization, required List<bool> inputBits}) JubJubNativePoint
Creates a combined hash code for a number of objects.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited