PoseidonSpec<F extends PastaFieldElement<F>> class abstract

Implementers

Constructors

PoseidonSpec(MdsGenerateResult<F> constants)
const

Properties

constants MdsGenerateResult<F>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fromBytes(List<int> bytes) → F
fullRounds() int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
partialRounds() int
rate() int
rateField() → F
sbox(F field) → F
toString() String
A string representation of this object.
inherited
width() int
zero() → F

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

isValidConstants(MdsGenerateResult<PastaFieldElement> constants, {int constantLength = 64, int width = 3}) bool