PoseidonUtils class

Constructors

PoseidonUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateConstants<F extends PastaFieldElement<F>>({required F fromBytes(List<int> bytes), required F zero, required F one, int rate = 2, int width = 3, int fullRounds = 8, int partialRounds = 56, int secureMds = 0}) MdsGenerateResult<F>
generateMds<F extends PastaFieldElement<F>>(Grain<F> grain, int t, int select, F one, F zero) MdsGenerateResult<F>
permute<F extends PastaFieldElement<F>>(List<F> state, PoseidonSpec<F> spec) → void
poseidonSponge<F extends PastaFieldElement<F>>(List<F> state, Absorbing<F>? input, PoseidonSpec<F> spec) Squeezing<F>

Constants

rate → const int
width → const int