CommitDomain class

Inheritance

Constructors

CommitDomain({required HashDomain context, required WnafBase<VestaFq, PallasPoint> r})
CommitDomain.create(String domain, {List<PallasAffinePoint>? sinsemillaS})
Constructs a new CommitDomainNative with a specific prefix string. sinsemillaS pre generated sinsemilaS
factory
CommitDomain.withSeperateDomain({required String hashDomain, required String blindDomain, List<PallasAffinePoint>? sinsemillaS})
Constructs a new CommitDomain from different values for hashDomain and blindDomain sinsemillaS pre generated sinsemilaS
factory

Properties

context HashDomain
final
hashCode int
The hash code for this object.
no setterinherited
r WnafBase<VestaFq, PallasPoint>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

commit({required List<bool> msg, required VestaFq r}) PallasPoint?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shortCommit({required List<bool> msg, required VestaFq r}) PallasFp?
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited