HashDomain class final

Inheritance

Constructors

HashDomain({required PallasPoint q, required List<PallasAffinePoint> sinsemillaS})
HashDomain.fromDomain(String domain, {List<int>? message, List<PallasAffinePoint>? sinsemillaS, bool withSeperator = false})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
q PallasPoint
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sinsemillaS List<PallasAffinePoint>
no setterinherited

Methods

hash(List<bool> msg) PallasFp?
Creates a combined hash code for a number of objects.
inherited
hashToPoint(List<bool> msg) PallasPoint?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pointAtIndex(int index) PastaAffinePoint<VestaFq, PallasFp, PallasPoint>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited