LimbBuffer class

Constructors

LimbBuffer(List<int> buffer)

Properties

buf List<int>
getter/setter pair
curIdx int
getter/setter pair
curLimb BigInt
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nextLimb BigInt
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(int idx) → (BigInt, BigInt)
Returns (curLimb, nextLimb). Only valid if idx is curIdx or curIdx+1.
incrementLimb() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited