BlockchainUtilsException class abstract

An abstract class 'BlockchainUtilsException' that implements the Exception interface. This class serves as a base for custom exceptions related to blockchain utility operations.

Inheritance
Implementers

Constructors

BlockchainUtilsException(String message, {Map<String, String?>? details})
Abstract field to hold the exception message.
const

Properties

details Map<String, String?>?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
relatedNetwork BlockchainNetwork?
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializationIdentifier BlockchainUtilsSerializationIdentifier
no setteroverride
serializationItems List<CborObject<Object?>?>
no setterinherited
variables List
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCbor() CborTagValue<CborObject<Object?>>
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited