IException class abstract

Implemented types
Mixed-in types
Implementers

Constructors

IException(String message, {Map<String, String?>? details})
const
IException.deserialize({List<int>? bytes, CborObject<Object?>? object})
factory

Properties

details Map<String, String?>?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
relatedNetwork BlockchainNetwork?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializationIdentifier SerializationIdentifier
no setteroverride
serializationItems List<CborObject<Object?>?>
no setteroverride
variables List
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCbor() CborTagValue<CborObject<Object?>>
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited