RPCError class

An exception class representing errors that occur during RPC (Remote Procedure Call) communication.

Inheritance

Constructors

RPCError({required String message, BlockchainNetwork? relatedNetwork, int? errorCode, Map<String, dynamic>? request, Map<String, dynamic>? jsonRpcErrpr, Map<String, String?>? details, int? statusCode})
Creates an instance of RPCError.
const
RPCError.deserialize({List<int>? bytes, CborObject<Object?>? object})
factory

Properties

details Map<String, String?>?
finalinherited
errorCode int?
The error code associated with the RPC error.
final
hashCode int
The hash code for this object.
no setterinherited
jsonRpcErrpr Map<String, dynamic>?
Details of the Json rpc error.
final
message String
finalinherited
relatedNetwork BlockchainNetwork?
final
request Map<String, dynamic>?
Details of the RPC request that resulted in the error.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializationIdentifier SerializationIdentifier
no setteroverride
serializationItems List<CborObject<Object?>?>
no setteroverride
statusCode int?
final
variables List
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCbor() CborTagValue<CborObject<Object?>>
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited