RequestLayoutParams<R extends LayoutRepository> class

Constructors

RequestLayoutParams({required LayoutAction action, required Map<String, dynamic> sourceOrResult, required int remainBytes, required R? repository})
const

Properties

action → LayoutAction
final
hashCode → int
The hash code for this object.
no setterinherited
remainBytes → int
final
repository → R?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceOrResult → Map<String, dynamic>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited