overflow constant
IntegerError
const overflow
Implementation
static const overflow = IntegerError(
"integer overflow: value cannot be represented in the target integer type",
);
static const overflow = IntegerError(
"integer overflow: value cannot be represented in the target integer type",
);