compareTo method

  1. @override
int compareTo(
  1. Uint256 other
)
override

Compares this object to another object.

Returns a value like a Comparator when comparing this to other. That is, it returns a negative integer if this is ordered before other, a positive integer if this is ordered after other, and zero if this and other are ordered together.

The other argument must be a value that is comparable to this object.

Implementation

@override
int compareTo(Uint256 other) {
  var cmp = _d3.compareTo(other._d3);
  if (cmp != 0) return cmp;
  cmp = _d2.compareTo(other._d2);
  if (cmp != 0) return cmp;
  cmp = _d1.compareTo(other._d1);
  if (cmp != 0) return cmp;
  return _d0.compareTo(other._d0);
}