operator >> method

Uint32 operator >>(
  1. int n
)

Logical right shift (the only kind that applies to an unsigned type). Right shift only shrinks magnitude, so this is always safe directly.

Implementation

Uint32 operator >>(int n) {
  final shift = n & 31;
  if (shift == 0) return this;
  return Uint32._(_value >>> shift);
}