ProtoBufferDecoder class

Constructors

ProtoBufferDecoder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode({required List<int> bytes, required ProtoMessageConfig messageConfig}) ProtoBufferDecoderResult
decodeFields(List<int> bytes, List<ProtoFieldConfig> tags, {ProtoSyntax syntax = ProtoSyntax.v3}) ProtoBufferDecoderResult
decodeVarint32(List<int> data, int offset, {bool sign = false}) LayoutDecodeResult<int>
decodeVarint64(List<int> bytes, ProtoFieldConfig config, {bool decodeWiretype = false, int offset = 0}) ProtoBufferDecodedField<BigInt>