ProtoBufferDecoderResult class
- Available extensions
Constructors
-
ProtoBufferDecoderResult({required List<
ProtoBufferDecodedField> fields, required ProtoSyntax syntax}) -
const
Properties
-
fields
→ List<
ProtoBufferDecodedField> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- syntax → ProtoSyntax
-
final
Methods
-
fieldExists(
int fieldNumber) → bool -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getBigInt<
T extends BigInt?> (int fieldNumber, {T? defaultValue}) → T -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getBool<
T extends bool?> (int fieldNumber, {T? defaultValue}) → T -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getBytes<
T extends List< (int> ?>int fieldNumber, {T? defaultValue}) → T -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getDouble<
T extends double?> (int fieldNumber, {T? defaultValue}) → T -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getEnum<
T extends ProtoEnumVariant?> (int fieldNumber, List< T> values, {T? defaultValue}) → T -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getInt<
T extends int?> (int fieldNumber, {T? defaultValue}) → T -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getList<
T extends Object> (int fieldNumber, {List< T> ? defaultValue}) → List<T> -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getListOfBytes(
int fieldNumber, {List< List< ? defaultValue}) → List<int> >List< int> > -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getListOfBytesOrEmpty(
int fieldNumber) → List< List< int> > -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getListOrEmpty<
T extends Object> (int fieldNumber) → List< T> -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getListOrNull<
T extends Object> (int fieldNumber) → List< T> ? -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getMap<
K extends Object, V extends Object> (int fieldNumber, {Map< K, V> ? defaultValue}) → Map<K, V> -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getMapField<
K extends Object, V extends Object> ({required int fieldNumber, required V valueMapper(Object? valye), required K keyMapper(Object? valye), Map< K, V> ? defaultValue}) → Map<K, V> -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getMapOrNull<
K extends Object, V extends Object> (int fieldNumber) → Map< K, V> ? -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getReapeatedEnum<
T extends ProtoEnumVariant> (int fieldNumber, List< T> values, {List<T> ? defaultValue}) → List<T> -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getReapeatedEnumOrNull<
T extends ProtoEnumVariant> (int fieldNumber, List< T> values, {List<T> ? defaultValue}) → List<T> ? -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getString<
T extends String?> (int fieldNumber, {T? defaultValue}) → T -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
getTagNumberField(
int fieldNumber) → ProtoBufferDecodedField? -
integerTo<
T extends Object?> (int fieldNumber, T convert(int)) → T -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
messageTo<
T extends Object?> (int fieldNumber, T convert(List< int> )) → T -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stringTo<
T extends Object?> (int fieldNumber, T convert(String)) → T -
Available on ProtoBufferDecoderResult, provided by the ExtProtocolBufferFiled extension
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited