ProtoMessageConfig class

Constructors

ProtoMessageConfig({ProtoSyntax syntax = ProtoSyntax.v3, List<ProtoOption> options = const [], List<ProtoFieldConfig> fields = const []})
const

Properties

fields List<ProtoFieldConfig>
final
hashCode int
The hash code for this object.
no setterinherited
options List<ProtoOption>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syntax ProtoSyntax
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited