ProtoOption class abstract

Mixed-in types
Implementers

Constructors

ProtoOption({required String name})
const
ProtoOption.parse({required String name, Object? value})
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Object?
no setter
variables → List
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stringify() → String
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited