ProtoWireType enum
Protobuf wire types as defined by the Protocol Buffers binary format.
Values
- varint → const ProtoWireType
-
0: Varint (variable-length integer) Used for: int32, int64, uint32, uint64, sint32, sint64, bool, enum
const ProtoWireType(0) - fixed64 → const ProtoWireType
-
1: 64-bit fixed-length Used for: fixed64, sfixed64, double
const ProtoWireType(1) - lengthDelimited → const ProtoWireType
-
2: Length-delimited Used for: string, bytes, embedded messages, packed repeated fields
const ProtoWireType(2) - fixed32 → const ProtoWireType
-
5: 32-bit fixed-length Used for: fixed32, sfixed32, float
const ProtoWireType(5)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
List< int> data, int offset, {ProtoWireType? expected, int? expectedTag}) → (ProtoWireType, int, int) -
fromValue(
int type) → ProtoWireType
Constants
-
values
→ const List<
ProtoWireType> - A constant List of the values in this enum, in order of their declaration.