Web3SecretStorageDefinationV3Exception class
- Inheritance
-
- Object
- IException
- BlockchainUtilsException
- Web3SecretStorageDefinationV3Exception
Constructors
-
Web3SecretStorageDefinationV3Exception.deserialize({List<
int> ? bytes, CborObject<Object?> ? object}) -
factory
Properties
-
details
→ Map<
String, String?> ? -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
finalinherited
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serializationIdentifier → BlockchainUtilsSerializationIdentifier
-
no setteroverride
-
serializationItems
→ List<
CborObject< Object?> ?> -
no setterinherited
- variables → List
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCbor(
) → CborTagValue< CborObject< Object?> > -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- unsuportedBackupContent ↔ Web3SecretStorageDefinationV3Exception
-
getter/setter pair
- wrongBackupPassword ↔ Web3SecretStorageDefinationV3Exception
-
getter/setter pair