CryptoParam class

Constructors

CryptoParam({required KDFParam kdf, required List<int> iv})
factory
CryptoParam.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
iv → List<int>
final
kdf → KDFParam
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode(List<int> password, List<int> data) → Map<String, dynamic>
encodeCbor(List<int> password, List<int> data, String uuid) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited