KDF2 class

A class implementing key derivation using the PBKDF2 algorithm.

Inheritance

Constructors

KDF2({required int iterations, required List<int> salt, required int dklen})
factory
KDF2.fromCbor(CborListValue<CborObject<Object?>> v)
factory
KDF2.fromJson(Map<String, dynamic> json)
factory

Properties

dklen → int
final
hashCode → int
The hash code for this object.
no setterinherited
iterations → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salt → List<int>
final
type → KDFMode
no setteroverride

Methods

cborEncode() → CborTagValue<CborObject<Object?>>
override
deriveKey(List<int> password) → List<int>
override
encode() → Map<String, dynamic>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited