GrpcHttpEndpoint class

Constructors

GrpcHttpEndpoint({required HttpRule httpRule})

Properties

hashCode → int
The hash code for this object.
no setterinherited
httpRule → HttpRule
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildRequest(Map<String, dynamic> message) → HttpRequestSpec
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited