HttpRule class

A fully parsed google.api.http rule: method + path template (+ optional additional bindings, which are just more HttpRules).

Constructors

HttpRule({required RequestMethod method, required String pathTemplate, required List<PathSegment> segments, String? body, List<HttpRule>? additionalBindings})

Properties

body String?
body option value: null (no body / GET-like), "*" (whole message is the body), or a field name (only that field is the body).
final
hashCode int
The hash code for this object.
no setterinherited
method RequestMethod
final
pathFieldPaths Set<String>
All full dotted field paths used as path variables.
no setter
pathFieldTopLevelNames Set<String>
All field names referenced by path variables, flattened (top-level name only, e.g. "user" for "user.address.city") — used to know which top-level fields must NOT be treated as query params even when the nested value used in the path is a child of them.
no setter
pathTemplate String
Raw path template string, e.g. "/cosmos/tx/v1beta1/{tx_hash}".
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
segments List<PathSegment>
Parsed segments of pathTemplate, split on '/'.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(String template, RequestMethod method, {String? body}) HttpRule