HttpRequestSpec class

The resolved request.

Constructors

HttpRequestSpec({required RequestMethod method, required String path, required Map<String, dynamic> queryParameters, Map<String, dynamic>? jsonBody})

Properties

hashCode int
The hash code for this object.
no setterinherited
jsonBody Map<String, dynamic>?
JSON-encodable body, or null if this request has no body (typical for GET / DELETE bindings).
final
method RequestMethod
final
path String
final
queryParameters Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode(String baseUrl) Uri
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited