BaseServiceErrorResponse class abstract
- Inheritance
-
- Object
- BaseServiceResponse
- BaseServiceErrorResponse
- Implementers
Constructors
- BaseServiceErrorResponse({required int statusCode, required bool validate})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
finalinherited
- type → ServiceResponseType
-
finalinherited
- validate → bool
-
final
Methods
-
cast<
E extends BaseServiceResponse> () → E -
inherited
-
defaultError(
) → RPCError -
findErrorMessage(
) → String -
getError(
) → Object? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
tryAsString(
) → String? -
tryFindErrorMessage(
) → String? -
tryFineErrorCode(
) → int? -
tryToJson(
) → Map< String, dynamic> ?
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited