BaseServiceSubscribtionRequest<IDENTIFIER, SERVICERESPONSE, EVENT extends BaseSubscribtionEvent<IDENTIFIER>, PARAMS extends BaseServiceRequestParams> class abstract

Inheritance
Mixed-in types

Properties

hashCode int
The hash code for this object.
no setterinherited
requestMethod RequestMethod
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializationIdentifier SerializationIdentifier
no setterinherited
serializationItems List<CborObject<Object?>?>
no setterinherited

Methods

buildRequest(int requestID) → PARAMS
inherited
buildUnsubscribeRequest(IDENTIFIER identifier, int requestID) → PARAMS
deserializeEvent(List<int> bytes) → EVENT
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onResonse(SERVICERESPONSE result) → IDENTIFIER
inherited
toCbor() CborTagValue<CborObject<Object?>>
inherited
toEvent(IDENTIFIER identifier, Object event) → EVENT?
toIdentifier(BaseServiceResponse response) → IDENTIFIER?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited