BaseSubscribtionEvent<IDENTIFIER> class abstract

Inheritance

Constructors

BaseSubscribtionEvent()

Properties

hashCode int
The hash code for this object.
no setterinherited
id → IDENTIFIER
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializationIdentifier SerializationIdentifier
no setterinherited
serializationItems List<CborObject<Object?>?>
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCbor() CborTagValue<CborObject<Object?>>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited