DefaultSubscribtionRequestResponse<IDENTIFIER, EVENT extends CborTagSerializable> class
- Implemented types
-
- BaseSubscribtionRequestResponse<
IDENTIFIER, EVENT>
- BaseSubscribtionRequestResponse<
Constructors
-
DefaultSubscribtionRequestResponse({required IDENTIFIER identifier, required Stream<
EVENT> stream}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- identifier → IDENTIFIER
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stream
→ Stream<
EVENT> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited