IGRPCServiceRequest<RESULT, PARAMS extends BaseGRPCServiceRequestParams> class
abstract
- Implemented types
-
- IServiceRequest<
RESULT, List< int> , PARAMS>
- IServiceRequest<
Constructors
- IGRPCServiceRequest()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildRequest(
int requestID) → PARAMS -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onResonse(
List< int> result) → RESULT -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited