IGrpcProvider<SERVICE extends IServiceProvider<BaseServiceRequestParams, BaseGRPCServiceRequestParams>, PARAMS extends IServiceRequestParams, GRPCPARAMS extends BaseGRPCServiceRequestParams> class abstract

Implemented types

Constructors

IGrpcProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service → SERVICE
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request<RESULT, SERVICERESPONSE>(IServiceRequest<RESULT, SERVICERESPONSE, PARAMS> request, {Duration? timeout}) Future<RESULT>
inherited
requestDynamic<RESULT, SERVICERESPONSE>(IServiceRequest<RESULT, SERVICERESPONSE, PARAMS> request, {Duration? timeout}) Future<SERVICERESPONSE>
inherited
requestOnce<RESULT>(IGRPCServiceRequest<RESULT, GRPCPARAMS> request, {Duration? timeout}) Future<List<RESULT>>
requestOnceAsync<RESULT>(IGRPCServiceRequest<RESULT, GRPCPARAMS> request, {Duration? timeout}) Future<List<RESULT>>
requestStream<RESULT>(IGRPCServiceRequest<RESULT, GRPCPARAMS> request, {Duration? timeout}) Stream<RESULT>
requestStreamAsync<RESULT>(IGRPCServiceRequest<RESULT, GRPCPARAMS> request, {Duration? timeout}) Future<Stream<RESULT>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited