IProvider<SERVICE extends IServiceProvider<BaseServiceRequestParams, BaseGRPCServiceRequestParams>, PARAMS extends IServiceRequestParams> class abstract

Implementers

Constructors

IProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service → SERVICE
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request<RESULT, SERVICERESPONSE>(IServiceRequest<RESULT, SERVICERESPONSE, PARAMS> request, {Duration? timeout}) Future<RESULT>
requestDynamic<RESULT, SERVICERESPONSE>(IServiceRequest<RESULT, SERVICERESPONSE, PARAMS> request, {Duration? timeout}) Future<SERVICERESPONSE>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited