IServiceRequestParams class abstract
- Mixed-in types
- Implementers
Constructors
- IServiceRequestParams()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serializationIdentifier → SerializationIdentifier
-
no setterinherited
-
serializationItems
→ List<
CborObject< Object?> ?> -
no setterinherited
Methods
-
encodeUrl(
String url) → Uri - Builds the final request URI.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCbor(
) → CborTagValue< CborObject< Object?> > -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited