ISubscribtionProvider<SERVICE extends IServiceProvider<BaseServiceRequestParams, BaseGRPCServiceRequestParams>, PARAMS extends BaseServiceRequestParams> class abstract

Implemented types

Constructors

ISubscribtionProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service → SERVICE
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request<RESULT, SERVICERESPONSE>(IServiceRequest<RESULT, SERVICERESPONSE, PARAMS> request, {Duration? timeout}) Future<RESULT>
inherited
requestDynamic<RESULT, SERVICERESPONSE>(IServiceRequest<RESULT, SERVICERESPONSE, PARAMS> request, {Duration? timeout}) Future<SERVICERESPONSE>
inherited
requestSubscribtion<IDENTIFIER, EVENT extends BaseSubscribtionEvent<IDENTIFIER>, SERVICERESPONSE>(BaseServiceSubscribtionRequest<IDENTIFIER, SERVICERESPONSE, EVENT, PARAMS> request, {Duration? timeout}) Future<BaseSubscribtionRequestResponse<IDENTIFIER, EVENT>>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited