RequestMethod enum
Supported HTTP verbs as they appear inside option (google.api.http) = { ... }.
Values
- post → const RequestMethod
-
const RequestMethod(0, "POST") - get → const RequestMethod
-
const RequestMethod(1, "GET") - put → const RequestMethod
-
const RequestMethod(2, "PUT") - patch → const RequestMethod
-
const RequestMethod(3, "PATCH") - delete → const RequestMethod
-
const RequestMethod(4, "DELETE") - custom → const RequestMethod
-
const RequestMethod(5, "CUSTOM")
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isGet → bool
-
no setter
- isPost → bool
-
no setter
- methodName → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromMethodName(
String? name) → RequestMethod -
fromName(
String? name) → RequestMethod -
fromValue(
int? value) → RequestMethod
Constants
-
values
→ const List<
RequestMethod> - A constant List of the values in this enum, in order of their declaration.