ServiceErrorResponse class
- Inheritance
-
- Object
- BaseServiceResponse
- BaseServiceErrorResponse
- ServiceErrorResponse
Constructors
Properties
- error → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
jsonError
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
finalinherited
- type → ServiceResponseType
-
finalinherited
- validate → bool
-
finalinherited
Methods
-
cast<
E extends BaseServiceResponse> () → E -
inherited
-
defaultError(
{BaseServiceRequestParams? request}) → RPCError -
override
-
findErrorMessage(
) → String -
override
-
getError(
) → Object? -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
tryAsString(
) → String? -
override
-
tryFindErrorMessage(
) → String? -
override
-
tryFineErrorCode(
) → int? -
override
-
tryToJson(
) → Map< String, dynamic> ? -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited