ServiceProtocol enum
Values
- http → const ServiceProtocol
-
const ServiceProtocol("HTTP", 0) - ssl → const ServiceProtocol
-
const ServiceProtocol("SSL", 1) - tcp → const ServiceProtocol
-
const ServiceProtocol("TCP", 2) - websocket → const ServiceProtocol
-
const ServiceProtocol("WebSocket", 3) - grpc → const ServiceProtocol
-
const ServiceProtocol("Grpc", 4)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isGrpc → bool
-
no setter
- isHttp → bool
-
no setter
- isSocket → bool
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int? value) → ServiceProtocol
Constants
-
values
→ const List<
ServiceProtocol> - A constant List of the values in this enum, in order of their declaration.