ServiceSuccessRespose class

Inheritance

Constructors

ServiceSuccessRespose({int statusCode = 200, required Object? response})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
response Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
finalinherited
type ServiceResponseType
finalinherited

Methods

cast<E extends BaseServiceResponse>() → E
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEncodingResponse<T>(ServiceReponseEncoding encoding) → T
override
toString() String
A string representation of this object.
inherited
tryToJson() Map<String, dynamic>?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited