CryptoSignerConst class

Constructors

CryptoSignerConst()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

curveSecp256k1 → CurveFp
final
generatorED25519 → EDPoint
final
generatorSecp256k1 → ProjectiveECCPoint
final
nist256 → ProjectiveECCPoint
The projective ECC point representing the secp256r1 elliptic curve.
final
nist256256Order → BigInt
The order of the secp256R1 elliptic curve.
final
nist256DigestLength → int
The length of the digest (or component) in bytes for the secp256r1 curve.
final
orderHalf → BigInt
Half of the order of the secp256R1 elliptic curve.
final
secp256k1Order → BigInt
final
secp256k1OrderHalf → BigInt
final