ETHVerifier class

Ethereum Verifier class for cryptographic operations, including signature verification.

Constructors

ETHVerifier.fromKeyBytes(List<int> keyBytes)
Factory method to create an ETHVerifier from a byte representation of a public key.
factory

Properties

edsaVerifyKey ECDSAVerifyKey
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verify(List<int> digest, List<int> signature, {bool hashMessage = true}) bool
Verifies an Ethereum signature against a message digest.
verifyPersonalMessage(List<int> message, List<int> signature, {bool hashMessage = true, int? payloadLength}) bool
Verifies an Ethereum signature of a personal message against the message digest.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getPublicKey(List<int> message, List<int> signature, {bool hashMessage = true, int? payloadLength}) ECDSAPublicKey?
Gets the recovered ECDSAPublicKey from a message and signature.