SubstrateEcdsaSigner class

Implemented types

Constructors

SubstrateEcdsaSigner.fromKeyBytes(List<int> keyBytes)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(List<int> digest, {bool hashMessage = true, List<int>? extraEntropy}) List<int>
override
signConst(List<int> digest, {bool hashMessage = true, List<int>? extraEntropy}) List<int>
override
signProsonalMessage(List<int> digest, {int? payloadLength}) List<int>
signProsonalMessageConst(List<int> digest, {int? payloadLength}) List<int>
toString() String
A string representation of this object.
inherited
toVerifyKey() SubstrateEcdsaVerifier
vrfSign(List<int> message, {List<int>? context, List<int>? extra}) List<int>
override
vrfSignConst(List<int> message, {List<int>? context, List<int>? extra}) List<int>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited