UUID class

Constructors

UUID()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromBuffer(List<int> buffer) → String
Converts a binary buffer to a UUIDv4 string.
generateUUIDv4() → String
Generates a version 4 (random) UUID (Universally Unique Identifier).
isValidUUIDv4(String uuid) → bool
Validates whether a string is a valid UUIDv4.
random() → String
toBuffer(String uuidString, {bool validate = true}) → List<int>
Converts a UUID string to a binary buffer.