ADANetwork enum

An enumeration of Ada Shelley address network tags.

Inheritance
Available extensions

Values

mainnet → const ADANetwork

Mainnet network tag with a value of 1.

const ADANetwork("mainnet", 1, 764824073)
testnet → const ADANetwork

Testnet network tag with a value of 0. This network does not exist anymore.

const ADANetwork("testnet", 0, 1097911063)
testnetPreview → const ADANetwork

Testnet network tag with a value of 0.

const ADANetwork("testnetPreview", 0, 2)
testnetPreprod → const ADANetwork

Testnet network tag with a value of 0.

const ADANetwork("testnetPreprod", 0, 1)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isTestnet bool
no setter
name String
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
protocolMagic int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromProtocolMagic(int? protocolMagic) ADANetwork
fromTag(int tag) ADANetwork
fromTags(int tag) List<ADANetwork>

Constants

values → const List<ADANetwork>
A constant List of the values in this enum, in order of their declaration.