IBip32ChildKeyDerivator class abstract
An abstract class that defines methods for BIP-32 key derivation.
- Implemented types
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deriveFromPublic(
{required Bip32PublicKey parent, required Bip32KeyIndex index, EllipticCurveTypes? type}) → Bip32ChildKey -
Derives a child public key from the given public key.
override
-
deriveFromSecret(
{required Bip32PrivateKey parent, required Bip32PublicKey ctx, required Bip32KeyIndex index, EllipticCurveTypes? type}) → Bip32ChildKey -
Derives a child private key from the given private and public keys.
override
-
isPublicDerivationSupported(
) → bool -
Checks if public key derivation is supported.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited