IBip32MstKeyGenerator class abstract
An abstract class that defines a method for generating master keys from a seed.
This class outlines a method for generating BIP-32 master keys from seed bytes.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateFromSeed(
List< int> seedBytes) → Bip32MasterKey -
Generates master keys from the given
seedBytes.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited