bip/bip/bip32/bip32_keys library
Classes
- Bip32KeyBase
- Bip32PrivateKey
- Represents a BIP32 private key with associated data such as the elliptic curve type, key data, and key network versions.
- Bip32PublicKey
- Represents a BIP32 public key with associated data such as the elliptic curve type, key data, and key network versions.