Bip38EcUtils class
Utility class for BIP38 encryption and decryption operations.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
deriveKeyHalves(
List< int> passpoint, List<int> addressHash, List<int> ownerEntropy) → (List<int> , List<int> ) - Derive key halves from passpoint, address hash, and owner entropy.
-
ownerEntropyNoLotSeq(
) → List< int> - Generate owner entropy without lot and sequence numbers.
-
ownerEntropyWithLotSeq(
int lotNum, int sequenceNum) → List< int> - Generate owner entropy with lot and sequence numbers.
-
ownerSaltFromEntropy(
List< int> ownerEntropy, bool hasLotSeq) → List<int> - Extract owner salt from owner entropy based on lot and sequence numbers.
-
passFactor(
String passphrase, List< int> ownerEntropy, bool hasLotSeq) → List<int> - Derive the pass factor for BIP38 encryption.
-
passPoint(
List< int> passfactor) → List<int> - Calculate the EC point for the pass factor.