Bip86Conf class
A configuration class for BIP86 that defines the key network versions and maps each supported BIP86Coin to its corresponding BipCoinConfig.
Constructors
Properties
- bitcoinMainNet → BipCoinConfig
-
Configuration for Bitcoin main net
final
- bitcoinTestNet → BipCoinConfig
-
Configuration for Bitcoin test net
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- bip86BtcKeyNetVer → const Bip32KeyNetVersions
- The key network version for the mainnet of Bitcoin.
- bip86BtcKeyNetVerTest → const Bip32KeyNetVersions
- The key network version for the testnet of Bitcoin.