EncodeAddressDefaultParams class

Constructors

EncodeAddressDefaultParams({required List<int> pubKey, int? ss58Format, List<int>? chainCode})

Properties

chainCode → List<int>?
final
hashCode → int
The hash code for this object.
no setterinherited
pubKey → List<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ss58Format → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited