DefaultZCryptoContext class
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sinsemillaS
→ List<
PallasNativePoint> -
latefinal
Methods
-
getCommitDomain(
String domain) → CommitDomainNative -
getPoseidonHash(
) → PoseidonHash< PallasNativeFp> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pseudoRando(
{required PallasNativeFp nk, required PallasNativeFp rho}) → PallasNativeFp -
$PRF^\mathsf{nfOrchard}(nk, \rho) := Poseidon(nk, \rho)$
override
-
sinsemillaCommit(
{required VestaNativeFq r, required List< bool> bits, String domain = "z.cash:Orchard-CommitIvk"}) → PallasNativePoint? -
override
-
sinsemillaShortCommit(
{required VestaNativeFq r, required List< bool> bits, String domain = "z.cash:Orchard-CommitIvk"}) → PallasNativeFp? -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited