OrchardZip32ChildKeyDerivator class
- Inheritance
-
- Object
- IChildKeyDerivator<
Bip32ChildKey, OrchardExtendedSpendingKey, OrchardExtendedFullViewKey?, Bip32KeyIndex> - OrchardZip32ChildKeyDerivator
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deriveExtendedKey(
{required OrchardExtendedSpendingKey parent, required OrchardExtendedFullViewKey parentFvk, required Bip32KeyIndex index, required ZCryptoContext context}) → (OrchardExtendedSpendingKey, OrchardFullViewingKey) -
deriveFingerPrint(
OrchardFullViewingKey fvk) → List< int> -
deriveFromPublic(
{required OrchardExtendedFullViewKey? parent, required Bip32KeyIndex index}) → Bip32ChildKey -
override
-
deriveFromSecret(
{required OrchardExtendedSpendingKey parent, OrchardExtendedFullViewKey? ctx, required Bip32KeyIndex index}) → Bip32ChildKey -
override
-
isPublicDerivationSupported(
) → bool -
Checks if public key derivation is supported.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited