OrchardExtendedFullViewKey class
- Inheritance
-
- Object
- CryptoKeyBase<
Bip32KeyData> - IZip32CryptoKey<
Bip32KeyData> - Zip32ExtendedFullViewKey<
OrchardIncomingViewingKey, Bip32KeyData> - OrchardExtendedFullViewKey
Constructors
- OrchardExtendedFullViewKey({required OrchardFullViewingKey fvk, required Bip32KeyData keyData})
-
OrchardExtendedFullViewKey.fromFullViewKey({required List<
int> bytes, required ZCryptoContext context, Bip32KeyData? keyData}) -
factory
-
OrchardExtendedFullViewKey.fromFullViewKeyUnchecked(List<
int> bytes, {Bip32KeyData? keyData}) -
factory
Properties
- fvk → OrchardFullViewingKey
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyData → Bip32KeyData
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variables → List
-
no setteroverride
Methods
-
incomingViewingKey(
ZCryptoContext context, {Bip44Changes scope = Bip44Changes.chainInt}) → OrchardIncomingViewingKey -
Returns the incoming viewing key (IVK) for this extended full-view key.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toHex(
{bool lowerCase = true, String? prefix = ""}) → String -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited