OrchardFullViewingKey class
- Mixed-in types
Constructors
- OrchardFullViewingKey({required OrchardSpendValidatingKey ak, required OrchardNullifierDerivingKey nk, required OrchardCommitIvkRandomness rivk})
-
const
-
OrchardFullViewingKey.fromBytes({required List<
int> bytes, required ZCryptoContext context}) -
factory
-
OrchardFullViewingKey.fromBytesUnchecked(List<
int> bytes) -
factory
- OrchardFullViewingKey.fromSpendKey(OrchardSpendingKey sk)
-
factory
Properties
- ak → OrchardSpendValidatingKey
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- nk → OrchardNullifierDerivingKey
-
final
- rivk → OrchardCommitIvkRandomness
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variables → List
-
no setteroverride
Methods
-
address(
{required Diversifier d, required Bip44Changes scope, required ZCryptoContext context}) → OrchardAddress -
addressAt(
{required DiversifierIndex j, required Bip44Changes scope, required ZCryptoContext context}) → OrchardAddress -
deriveDkOvk(
) → (OrchardDiversifierKey, OrchardOutgoingViewingKey) -
deriveInternal(
) → OrchardFullViewingKey -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rivkFromScope(
Bip44Changes scope) → OrchardCommitIvkRandomness -
scopeForAddress(
{required OrchardAddress address, required ZCryptoContext context}) → Bip44Changes? -
toBytes(
) → List< int> -
toIvk(
{required Bip44Changes scope, required ZCryptoContext context}) → OrchardIncomingViewingKey -
toOvk(
Bip44Changes scope) → OrchardOutgoingViewingKey -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited