OrchardSpendingKey class
- Mixed-in types
Constructors
-
OrchardSpendingKey(List<
int> sk) -
OrchardSpendingKey.fromBytes({required List<
int> bytes, required ZCryptoContext context}) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
publicFields
→ List<
Object?> -
Public, non-secret fields that can be compared normally.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
secretFields
→ List<
List< int> > -
Secret fields that MUST be compared in constant time.
no setteroverride
-
sk
→ List<
int> -
final
Methods
-
constantEquality(
OrchardSpendingKey other) → bool -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → List< int> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited