SaplingZip32ChildKeyDerivator class
- Inheritance
-
- Object
- IChildKeyDerivator<
Bip32ChildKey, SaplingExtendedSpendingKey, SaplingExtendedSpendingKey?, Bip32KeyIndex> - SaplingZip32ChildKeyDerivator
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deriveChildOvk(
{required SaplingOutgoingViewingKey parentOvk, required List< int> childSk}) → SaplingOutgoingViewingKey -
deriveExpandedSpendingKey(
{required SaplingExtendedSpendingKey parent, required Bip32KeyIndex index}) → SaplingExtendedSpendingKey -
deriveFromPublic(
{SaplingExtendedSpendingKey? parent, required Bip32KeyIndex index}) → Bip32ChildKey -
override
-
deriveFromSecret(
{required SaplingExtendedSpendingKey parent, SaplingExtendedSpendingKey? ctx, required Bip32KeyIndex index}) → Bip32ChildKey -
override
-
isPublicDerivationSupported(
) → bool -
Checks if public key derivation is supported.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited