MoneroConf class
A configuration class for Monero that defines the key network versions and maps each supported MoneroCoins to its corresponding BipCoinConfig.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mainnet → MoneroCoinConf
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stagenet → MoneroCoinConf
-
final
- testnet → MoneroCoinConf
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited