CborIterableObject<T extends Iterable<CborObject<Object?> > > class
abstract
Iterable
- Inheritance
-
- Object
- CborObject<
T> - CborIterableObject
- Implementers
- Available extensions
Constructors
- CborIterableObject(T value)
-
const
Properties
- encoding → CborIterableEncodingType
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
An abstract property representing the dynamic value contained in the CBOR object.
finalinherited
- variables → List
-
no setterinherited
Methods
-
allObjectsAs<
T extends CborObject< (Object?> >) → List< T> -
Available on CborIterableObject<
Return all CBOR objects as a List<Iterable< , provided by the ExtCborListExtensions extensionCborObject< >Object?> >T>. -
allRawValuesAs<
T> () → List< T> -
Available on CborIterableObject<
Return all raw values as a List<Iterable< , provided by the ExtCborListExtensions extensionCborObject< >Object?> >T>. -
cast<
E extends CborObject< (Object?> >) → E -
inherited
-
encode(
) → List< int> -
Encode the object's value to its CBOR representation and return it as a
List<int>.inherited -
getValue(
) → Object? -
inherited
-
hasIndex(
int index) → bool -
Available on CborIterableObject<
ReturnsIterable< , provided by the ExtCborListExtensions extensionCborObject< >Object?> >trueifindexis valid (within list bounds). -
isTypeAt<
T extends CborObject< (Object?> >int index) → bool -
Available on CborIterableObject<
Checks whether the element atIterable< , provided by the ExtCborListExtensions extensionCborObject< >Object?> >indexis of typeT. -
listAt<
T extends CborObject< (Object?> ?>int index, {bool emptyOnNull = false}) → List< T> -
Available on CborIterableObject<
Returns element atIterable< , provided by the ExtCborListExtensions extensionCborObject< >Object?> >indexas a list ofT. IfemptyOnNullis true and index is out of bounds → returns[]. -
mapAt<
K extends CborObject< (Object?> , V extends CborObject<Object?> >int index) → Map< K, V> -
Available on CborIterableObject<
Returns element atIterable< , provided by the ExtCborListExtensions extensionCborObject< >Object?> >indexas a typed map. -
maybeObjectAt<
E, T extends CborObject< (Object?> >int index, E mapper(T e)) → E? -
Available on CborIterableObject<
Attempt to transform the CBOR object atIterable< , provided by the ExtCborListExtensions extensionCborObject< >Object?> >indexusingmapperif it's typeT, or return null. -
maybeRawMapAt<
K, V> (int index) → Map< K, V> ? -
Available on CborIterableObject<
Iterable< , provided by the ExtCborListExtensions extensionCborObject< >Object?> > -
maybeRawValueAt<
E, T> (int index, E mapper(T v)) → E? -
Available on CborIterableObject<
Attempt to transform the raw value atIterable< , provided by the ExtCborListExtensions extensionCborObject< >Object?> >indexusingmapper, or return null. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
objectAt<
T extends CborObject< (Object?> ?>int index) → T -
Available on CborIterableObject<
Returns the CBOR object atIterable< , provided by the ExtCborListExtensions extensionCborObject< >Object?> >indexas typeT. -
rawMapAt<
K, V> (int index) → Map< K, V> -
Available on CborIterableObject<
Iterable< , provided by the ExtCborListExtensions extensionCborObject< >Object?> > -
rawValueAt<
T extends Object?> (int index) → T -
Available on CborIterableObject<
Returns the raw underlying Dart value atIterable< , provided by the ExtCborListExtensions extensionCborObject< >Object?> >indexas typeT. -
sublist<
T extends CborObject< (Object?> >int start, [int? end]) → CborListValue< T> -
Available on CborIterableObject<
Iterable< , provided by the ExtCborListExtensions extensionCborObject< >Object?> > -
toCborHex(
) → String -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited