CborNumeric class abstract

Implemented types
Implementers
Available extensions

Constructors

CborNumeric()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
An abstract property representing the dynamic value contained in the CBOR object.
finalinherited

Methods

cast<T extends CborObject>() → T

Available on CborObject, provided by the QuickCastingCbor extension

encode() → List<int>
Encode the object's value to its CBOR representation and return it as a List<int>.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBigInt() → BigInt
Convert the CborNumeric object to a BigInt.
toCborHex() → String
Convert the object's CBOR representation to a hexadecimal string.
inherited
toInt() → int
Convert the CborNumeric object to an integer.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getCborNumericValue(CborNumeric val) → BigInt
Retrieve the numeric value from a CborNumeric object and return it as a BigInt. This function is used to extract the numeric value from different CborNumeric subtypes.