RistrettoPoint class
A class representing a RistrettoPoint, a point on an elliptic curve in the Ristretto255 group, derived from an Edwards curve point.
- Inheritance
-
- Object
- ECPoint<
BigInt, BaseExtendedPointNative> - BaseExtendedPointNative
- EDPoint
- RistrettoPoint
Constructors
-
RistrettoPoint.fromBytes(List<
int> bytes, {CurveED? curveEdTw}) -
Factory method to create a RistrettoPoint from a byte representation.
factory
-
RistrettoPoint.fromEdwardBytes(List<
int> bytes) -
factory
- RistrettoPoint.fromEdwardsPoint(EDPoint point)
-
Create a RistrettoPoint from an EdwardsPoint.
factory
-
RistrettoPoint.fromUniform(List<
int> hash) -
Factory method to create a RistrettoPoint from a uniform byte representation.
factory
Properties
- curve → CurveED
-
The Edwards curve associated with this point.
finalinherited
- generator → bool
-
Indicates if this point is a generator point.
finalinherited
- hashCode → int
-
Calculates the hash code for the Edwards curve point.
no setterinherited
- order → BigInt?
-
The order of the point (null if not set).
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- t → BigInt
-
no setterinherited
- x → BigInt
-
Get the x-coordinate of the Edwards curve point.
no setterinherited
- y → BigInt
-
Get the y-coordinate of the Edwards curve point.
no setterinherited
- z → BigInt
-
no setterinherited
Methods
-
cast<
T extends ECPoint< (SCALAR, POINT> >) → T -
inherited
-
double(
) → EDPoint -
Double an Edwards curve point.
inherited
-
getCoords(
) → List< BigInt> -
inherited
-
isZero(
) → bool -
Checks if the Edwards curve point represents the point at infinity.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scale(
) → EDPoint -
Scale the Edwards curve point.
inherited
-
toBytes(
) → List< int> -
convert the RistrettoPoint to a byte array.
override
-
toEdwardBytes(
) → List< int> - Converts the RistrettoPoint to a byte array in Edwards curve encoding.
-
toHex(
) → String -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator *(
BigInt other) → RistrettoPoint -
multiply a RistrettoPoint by another edward point.
override
-
operator +(
BaseExtendedPointNative other) → RistrettoPoint -
add a RistrettoPoint to another edward point.
override
-
operator ==(
Object other) → bool -
Equality operator for comparing two Edwards curve points.
inherited
-
operator unary-(
) → RistrettoPoint - negate a RistrettoPoint.
-
operator unary-(
) → EDPoint -
inherited
Static Methods
-
isOdd(
BigInt num, BigInt modulo) → bool - Check if a BigInt number is odd with respect to a given modulo.
-
mapToPoint(
BigInt r0) → EDPoint - Maps a BigInt 'r0' to an Edwards curve point (EDPoint).
-
positiveMod(
BigInt a, BigInt b) → BigInt - Calculates the positive remainder of two BigInt values.
-
sqrtUV(
BigInt u, BigInt v) → (bool, BigInt) - sqrt u/v