SchnorrkelMiniSecretKey class
The SchnorrkelMiniSecretKey class represents a mini-secret key used for generating Schnorr key pairs.
Members:
_bytes: A List<int> containing the bytes of the mini-secret key.
Constructors
-
SchnorrkelMiniSecretKey.fromBytes(List<
int> keyBytes) -
Creates a SchnorrkelMiniSecretKey instance from a byte representation.
The input bytes are expected to have the correct length for a mini-secret key.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → List< int> - mini-secret key as bytes.
-
toSecretKey(
[ExpansionMode mode = ExpansionMode.ed25519]) → SchnorrkelSecretKey - Converts the SchnorrkelSecretKey into a full secret key using a specified expansion mode.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited