SchnorrkelSignature class
Represents a Schnorrkel digital signature.
Constructors
-
SchnorrkelSignature.fromBytes(List<
int> signatureBytes) -
Creates a signature from raw bytes.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
r
→ List<
int> -
Returns the 'r' component of the signature.
no setter
- rBigint → BigInt
-
Converts the 'r' component to a BigInt.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
s
→ List<
int> -
Returns the 's' component of the signature.
no setter
- sBigint → BigInt
-
Converts the 's' component to a BigInt.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → List< int> - Converts the signature to raw bytes with a schnorrkel marker.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited