G1AffinePoint class
BLS12-381 G1 group in projective coordinates (x : y : z).
- Inheritance
- Mixed-in types
Constructors
- G1AffinePoint({required Bls12Fp x, required Bls12Fp y, required bool infinity})
- G1AffinePoint.conditionalSelect(G1AffinePoint a, G1AffinePoint b, bool choice)
-
factory
-
G1AffinePoint.fromBytes(List<
int> bytes) -
Creates a G1 affine point from bytes, validating that it is on-curve and in the correct subgroup.
factory
-
G1AffinePoint.fromBytesUnchecked(List<
int> bytes) -
Creates a G1 affine point from bytes without checking curve or subgroup validity.
factory
- G1AffinePoint.fromProjective(G1Projective p)
-
factory
- G1AffinePoint.generator()
-
factory
- G1AffinePoint.identity()
-
factory
Properties
Methods
-
cast<
T extends ECPoint< (SCALAR, POINT> >) → T -
inherited
-
double(
) → G1Projective -
Point doubling.
override
-
isIdentity(
) → bool -
check identity
override
-
isOnCurve(
) → bool - Checks whether the point satisfies the BLS12-381 curve equation in projective form.
-
isTorsionFree(
) → bool - Checks whether the point is in the correct G1 subgroup (torsion-free).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
{PubKeyModes mode = PubKeyModes.compressed}) → List< int> -
Serializes the point to bytes in either compressed or uncompressed form.
override
-
toHex(
) → String -
inherited
-
toProjective(
) → G1Projective - Converts this affine point to its projective representation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator *(
JubJubFq rhs) → G1Projective -
Scalar multiplication using non-native field elements.
override
-
operator +(
Bls12Point< G1Projective> rhs) → G1Projective -
Point addition.
override
-
operator -(
Bls12Point< G1Projective> rhs) → G1Projective -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator unary-(
) → G1AffinePoint