G1NativeProjective class
BLS12-381 G1 group in projective coordinates (x : y : z).
- Inheritance
Constructors
- G1NativeProjective({required Bls12NativeFp x, required Bls12NativeFp y, required Bls12NativeFp z})
- G1NativeProjective.conditionalSelect(G1NativeProjective a, G1NativeProjective b, bool choice)
-
factory
- G1NativeProjective.fromAffine(G1NativeAffinePoint affine)
-
factory
-
G1NativeProjective.fromBytes(List<
int> bytes) -
Creates a G1 affine point from bytes, validating that it is on-curve and in the correct subgroup.
factory
-
G1NativeProjective.fromBytesUnchecked(List<
int> bytes) -
Creates a G1 point from bytes without checking curve or subgroup validity.
factory
- G1NativeProjective.generator()
-
factory
- G1NativeProjective.identity()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- x → Bls12NativeFp
-
final
- y → Bls12NativeFp
-
final
- z → Bls12NativeFp
-
final
Methods
-
cast<
T extends ECPoint< (SCALAR, POINT> >) → T -
inherited
-
clearCofactor(
) → G1NativeProjective - Clears the G1 cofactor by subtracting mulByX from the point.
-
copyWith(
{Bls12NativeFp? x, Bls12NativeFp? y, Bls12NativeFp? z}) → G1NativeProjective -
double(
) → G1NativeProjective -
Point doubling.
override
-
isIdentity(
) → bool -
check identity
override
-
isOnCurve(
) → bool - Checks whether the point satisfies the BLS12-381 curve equation in projective form.
-
mulBy3b(
Bls12NativeFp a) → Bls12NativeFp -
mulByX(
) → G1NativeProjective -
Multiply this point by
BLS_Xusing double-and-add -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAffine(
) → G1NativeAffinePoint -
toBytes(
{PubKeyModes mode = PubKeyModes.compressed}) → List< int> -
Serializes the point to bytes in either compressed or uncompressed form.
override
-
toHex(
) → String -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator *(
JubJubNativeFq rhs) → G1NativeProjective -
Scalar multiplication using native field elements.
override
-
operator +(
Bls12NativePoint< G1NativeProjective> rhs) → G1NativeProjective -
Point addition using native (single BigInt) field arithmetic.
override
-
operator -(
Bls12NativePoint< G1NativeProjective> rhs) → G1NativeProjective -
operator ==(
Object other) → bool -
The equality operator.
override
-
operator unary-(
) → G1NativeProjective