G2AffinePoint class
BLS12-381 G2 group afiine in projective coordinates (x : y : z) over GF(p²).
- Inheritance
- Mixed-in types
Constructors
- G2AffinePoint({required Bls12Fp2 x, required Bls12Fp2 y, required bool infinity})
- G2AffinePoint.conditionalSelect(G2AffinePoint a, G2AffinePoint b, bool choice)
-
factory
-
G2AffinePoint.fromBytes(List<
int> bytes) -
Creates a G2 affine point from bytes, validating that it is on-curve and in the correct subgroup.
factory
-
G2AffinePoint.fromBytesUnchecked(List<
int> bytes) -
Creates a G2 affine point from bytes without checking curve or subgroup validity.
factory
- G2AffinePoint.fromProjective(G2Projective p)
-
factory
- G2AffinePoint.generator()
-
generator
factory
- G2AffinePoint.identity()
-
identity element
factory
Properties
Methods
-
cast<
T extends ECPoint< (SCALAR, POINT> >) → T -
inherited
-
double(
) → G2Projective -
Point doubling.
override
-
isIdentity(
) → bool -
check identity
override
-
isOnCurve(
) → bool - Checks whether the point satisfies the BLS12-381 curve equation in projective form.
-
isTorsionFree(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
{PubKeyModes mode = PubKeyModes.compressed}) → List< int> -
Serializes the point to bytes in either compressed or uncompressed form.
override
-
toCompressed(
) → List< int> -
toHex(
) → String -
inherited
-
toProjective(
) → G2Projective -
toString(
) → String -
A string representation of this object.
inherited
-
toUncompressed(
) → List< int>
Operators
-
operator *(
JubJubFq rhs) → G2Projective -
Scalar multiplication using non-native field elements.
override
-
operator +(
Bls12Point< G2Projective> rhs) → G2Projective -
Point addition.
override
-
operator -(
Bls12Point< G2Projective> rhs) → G2Projective -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator unary-(
) → G2AffinePoint