G2NativeAffinePoint class
BLS12-381 G2 group affine in projective coordinates (x : y : z) over GF(p²).
- Inheritance
- Mixed-in types
Constructors
- G2NativeAffinePoint({required Bls12NativeFp2 x, required Bls12NativeFp2 y, required bool infinity})
- G2NativeAffinePoint.conditionalSelect(G2NativeAffinePoint a, G2NativeAffinePoint b, bool choice)
-
factory
-
G2NativeAffinePoint.fromBytes(List<
int> bytes, {bool check = true}) -
Creates a G2 point from bytes, validating that it is on-curve and in the correct subgroup.
factory
-
G2NativeAffinePoint.fromBytesUnchecked(List<
int> bytes) -
Creates a G2 affine point from bytes without checking curve or subgroup validity.
factory
- G2NativeAffinePoint.fromProjective(G2NativeProjective p)
-
factory
- G2NativeAffinePoint.generator()
-
generator
factory
- G2NativeAffinePoint.identity()
-
identity element
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- infinity → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- variables → List
-
no setteroverride
- x → Bls12NativeFp2
-
final
- y → Bls12NativeFp2
-
final
Methods
-
cast<
T extends ECPoint< (SCALAR, POINT> >) → T -
inherited
-
double(
) → G2NativeProjective -
Point doubling.
override
-
isIdentity(
) → bool -
check identity
override
-
isOnCurve(
) → bool - Checks whether the point satisfies the BLS12-381 curve equation in projective form.
-
isTorsionFree(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
{PubKeyModes mode = PubKeyModes.compressed}) → List< int> -
Serializes the point to bytes in either compressed or uncompressed form.
override
-
toCompressed(
) → List< int> -
toHex(
) → String -
inherited
-
toProjective(
) → G2NativeProjective -
toString(
) → String -
A string representation of this object.
inherited
-
toUncompressed(
) → List< int>
Operators
-
operator *(
JubJubNativeFq rhs) → G2NativeProjective -
Scalar multiplication using native field elements.
override
-
operator +(
Bls12NativePoint< G2NativeProjective> rhs) → G2NativeProjective -
Point addition using native (single BigInt) field arithmetic.
override
-
operator -(
Bls12NativePoint< G2NativeProjective> rhs) → G2NativeProjective -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator unary-(
) → G2NativeAffinePoint