MillerLoopResultBls12 class
Constructors
- MillerLoopResultBls12(Bls12NativeFp12 inner)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inner → Bls12NativeFp12
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
finalExponentiation(
) → GtNative -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited