PedersenUtils class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
findGroupHash<T extends JubJubScalar<T>, E extends BaseJubJubPoint<T, E>>({required List<int> message, required List<int> personalization, required E fromBytes(List<int> bytes)})
→ E
-
-
generateHash<T extends JubJubScalar<T>, E extends BaseJubJubPoint<T, E>>(E fromBytes(List<int> bytes), {String personalization = "Zcash_PH", int length = 6})
→ List<E>
-
-
generatePedersenHashExpTable<T extends JubJubScalar<T>, E extends BaseJubJubPoint<T, E>>({required E fromBytes(List<int> bytes), required E identity})
→ List<List<List<E>>>
-