P128Pow5T3Fq class
- Inheritance
-
- Object
- PoseidonSpec<
VestaFq> - P128Pow5T3Fq
Constructors
-
P128Pow5T3Fq({MdsGenerateResult<
VestaFq> ? constants}) -
factory
Properties
-
constants
→ MdsGenerateResult<
VestaFq> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fromBytes(
List< int> bytes) → VestaFq -
override
-
fullRounds(
) → int -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
partialRounds(
) → int -
inherited
-
rate(
) → int -
inherited
-
rateField(
) → VestaFq -
override
-
sbox(
VestaFq field) → VestaFq -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
width(
) → int -
inherited
-
zero(
) → VestaFq -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited