P128Pow5T3NativeFp class
- Inheritance
-
- Object
- PoseidonSpec<
PallasNativeFp> - P128Pow5T3NativeFp
Constructors
-
P128Pow5T3NativeFp({MdsGenerateResult<
PallasNativeFp> ? constants}) -
factory
Properties
-
constants
→ MdsGenerateResult<
PallasNativeFp> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fromBytes(
List< int> bytes) → PallasNativeFp -
override
-
fullRounds(
) → int -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
partialRounds(
) → int -
inherited
-
rate(
) → int -
inherited
-
rateField(
) → PallasNativeFp -
override
-
sbox(
PallasNativeFp field) → PallasNativeFp -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
width(
) → int -
inherited
-
zero(
) → PallasNativeFp -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited