BlockchainUtilsException class abstract
An abstract class 'BlockchainUtilsException' that implements the Exception interface. This class serves as a base for custom exceptions related to blockchain utility operations.
- Inheritance
-
- Object
- IException
- BlockchainUtilsException
- Implementers
- AddressConverterException
- AmountConverterException
- ArgumentException
- B64ConverterException
- Base58ChecksumError
- Bech32Error
- Bip32KeyError
- Bip32PathError
- Bip44DepthError
- CastFailedException
- CborException
- CborSerializableException
- CryptoException
- ElectrumException
- JsonParserError
- LayoutException
- MnemonicException
- MoneroKeyError
- PedersenHashException
- ProtoException
- SS58ChecksumError
- StateException
- SubstrateKeyError
- SubstratePathError
- Utf8Exception
- Web3SecretStorageDefinationV3Exception
- ZcashKeyError
- Zip32Error
Constructors
-
BlockchainUtilsException(String message, {Map<
String, String?> ? details}) -
Abstract field to hold the exception message.
const
Properties
-
details
→ Map<
String, String?> ? -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
finalinherited
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serializationIdentifier → BlockchainUtilsSerializationIdentifier
-
no setteroverride
-
serializationItems
→ List<
CborObject< Object?> ?> -
no setterinherited
- variables → List
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCbor(
) → CborTagValue< CborObject< Object?> > -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited