RPCError class
An exception class representing errors that occur during RPC (Remote Procedure Call) communication.
- Inheritance
-
- Object
- IException
- RPCError
Constructors
Properties
-
details
→ Map<
String, String?> ? -
finalinherited
- errorCode → int?
-
The error code associated with the RPC error.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
jsonRpcErrpr
→ Map<
String, dynamic> ? -
Details of the Json rpc error.
final
- message → String
-
finalinherited
-
final
-
request
→ Map<
String, dynamic> ? -
Details of the RPC request that resulted in the error.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serializationIdentifier → SerializationIdentifier
-
no setteroverride
-
serializationItems
→ List<
CborObject< Object?> ?> -
no setteroverride
- statusCode → int?
-
final
- variables → List
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCbor(
) → CborTagValue< CborObject< Object?> > -
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited