ProtoOptionHttp class
- Inheritance
-
- Object
- ProtoOption
- ProtoOptionHttp
Constructors
- ProtoOptionHttp({required String name, required RequestMethod method, required String path, String? bodyField})
-
const
- ProtoOptionHttp.parse(String name, Object? value)
-
factory
Properties
- bodyField → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → RequestMethod
-
final
- name → String
-
finalinherited
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → Object?
-
no setteroverride
- variables → List
-
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
stringify(
) → String -
override
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited