ProtoUtils class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
googleDurationFromJson(
String value) → ({int nanos, BigInt seconds}) -
googleDurationToJson(
BigInt seconds, int nanos, {bool asNanos = false}) → String - Converts a protobuf Duration to its JSON representation.
-
timestampFromRfc3339(
String input) → ({int nanos, int seconds}) -
timestampToRfc3339(
int seconds, int nanos) → String