BaseServiceRequestParams class abstract
- Inheritance
-
- Object
- IServiceRequestParams
- BaseServiceRequestParams
Constructors
-
BaseServiceRequestParams({required Map<
String, String> headers, required RequestMethod requestMethod, required int requestID, required ServiceReponseEncoding responseEncoding, required List<int> ? bodyBytes, required String? bodyString, String? path, List<int> ? successStatusCodes, List<int> ? errorStatusCodes, BlockchainNetwork? network}) -
const
Properties
-
bodyBytes
→ List<
int> ? -
final
- bodyString → String?
-
final
-
errorStatusCodes
→ List<
int> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
final
- network → BlockchainNetwork?
-
final
- path → String?
-
final
- requestID → int
-
final
- requestMethod → RequestMethod
-
final
- responseEncoding → ServiceReponseEncoding
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serializationIdentifier → SerializationIdentifier
-
no setterinherited
-
serializationItems
→ List<
CborObject< Object?> ?> -
no setterinherited
-
successStatusCodes
→ List<
int> ? -
final
Methods
-
encodeBody(
{ServiceProtocol protocol = ServiceProtocol.http}) → List< int> ? - Encodes the request payload into bytes.
-
encodeUrl(
String url) → Uri -
Builds the final request URI.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCbor(
) → CborTagValue< CborObject< Object?> > -
inherited
-
toEncodingResponse<
T> (BaseServiceResponse response, {ServiceReponseEncoding? encoding}) → T - Converts a BaseServiceResponse into the specified encoding type.
-
toJson(
) → Map< String, dynamic> -
toResponse(
Object? response, {int statusCode = 200}) → BaseServiceResponse - Decodes a raw service response into a BaseServiceResponse.
-
toString(
) → String -
A string representation of this object.
inherited
-
tryEncodingResponse<
T> (BaseServiceResponse response, {ServiceReponseEncoding? encoding}) → T? - Attempts to convert a successful response to the requested encoding type.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited