BaseServiceSuccessRespose class abstract
- Inheritance
-
- Object
- BaseServiceResponse
- BaseServiceSuccessRespose
- Implementers
Constructors
- BaseServiceSuccessRespose({int statusCode = 200})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
finalinherited
- type → ServiceResponseType
-
finalinherited
Methods
-
cast<
E extends BaseServiceResponse> () → E -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toEncodingResponse<
T> (ServiceReponseEncoding encoding) → T -
toString(
) → String -
A string representation of this object.
inherited
-
tryToJson(
) → Map< String, dynamic> ?
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited