IServiceProvider<HTTPWEBSOCKETPARAMS extends BaseServiceRequestParams, GRPCPARAM extends BaseGRPCServiceRequestParams> class
abstract
mixin
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
doGrpcRequest(
GRPCPARAM params, {Duration? timeout}) → Future< List< int> > -
doGrpcRequestStream(
GRPCPARAM params, {Duration? timeout}) → Stream< List< int> > -
doGrpcRequestStreamAsync(
GRPCPARAM params, {Duration? timeout}) → Future< Stream< List< >int> > -
doRequest(
HTTPWEBSOCKETPARAMS params, {Duration? timeout}) → Future< BaseServiceResponse> -
doSubscribtionRequest(
{required HTTPWEBSOCKETPARAMS params, required BaseServiceSubscribtionRequest< dynamic, dynamic, BaseSubscribtionEvent, HTTPWEBSOCKETPARAMS> request, Duration? timeout}) → Future<BaseServiceSubscribtionResponse> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited