ETHSigner class
Ethereum Signer class for cryptographic operations, including signing and verification.
Constructors
-
ETHSigner.fromKeyBytes(List<
int> keyBytes) -
Factory method to create an ETHSigner from a byte representation of a private key.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sign(
List< int> digest, {bool hashMessage = true, List<int> ? extraEntropy}) → ETHSignature -
signConst(
List< int> digest, {bool hashMessage = true, List<int> ? extraEntropy}) → ETHSignature -
signProsonalMessage(
List< int> digest, {int? payloadLength, List<int> ? extraEntropy}) → List<int> -
signProsonalMessageConst(
List< int> digest, {int? payloadLength, List<int> ? extraEntropy}) → List<int> -
toString(
) → String -
A string representation of this object.
inherited
-
toVerifyKey(
) → ETHVerifier - Converts the ETHSigner to an ETHVerifier for verification purposes.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited